@@ -201,17 +201,17 @@ KeyframeEffectReadOnly::SetKeyframes(JSContext* aContext,
     if (styleContext->IsGecko()) {
 #ifdef MOZ_OLD_STYLE
       auto gecko = styleContext->AsGecko();
-      SetKeyframes(Move(keyframes), gecko);
+      SetKeyframes(std::move(keyframes), gecko);
 #else
       MOZ_CRASH("old style system disabled");
 #endif
     } else {
-      SetKeyframes(Move(keyframes), styleContext->AsServo());
+      SetKeyframes(std::move(keyframes), styleContext->AsServo());
     }
   } else {
     // SetKeyframes has the same behavior for null StyleType* for
     // both backends, just pick one and use it.
-    SetKeyframes(Move(keyframes), (ServoStyleContext*) nullptr);
+    SetKeyframes(std::move(keyframes), (ServoStyleContext*) nullptr);
   }
 }
 
@@ -220,7 +220,7 @@ void
 KeyframeEffectReadOnly::SetKeyframes(nsTArray<Keyframe>&& aKeyframes,
                                      GeckoStyleContext* aStyleContext)
 {
-  DoSetKeyframes(Move(aKeyframes), Move(aStyleContext));
+  DoSetKeyframes(std::move(aKeyframes), std::move(aStyleContext));
 }
 #endif
 
@@ -229,7 +229,7 @@ KeyframeEffectReadOnly::SetKeyframes(
   nsTArray<Keyframe>&& aKeyframes,
   const ServoStyleContext* aComputedValues)
 {
-  DoSetKeyframes(Move(aKeyframes), aComputedValues);
+  DoSetKeyframes(std::move(aKeyframes), aComputedValues);
 }
 
 template<typename StyleType>
@@ -248,7 +248,7 @@ KeyframeEffectReadOnly::DoSetKeyframes(nsTArray<Keyframe>&& aKeyframes,
     return;
   }
 
-  mKeyframes = Move(aKeyframes);
+  mKeyframes = std::move(aKeyframes);
   KeyframeUtils::DistributeKeyframes(mKeyframes);
 
   if (mAnimation && mAnimation->IsRelevant()) {
@@ -329,7 +329,7 @@ KeyframeEffectReadOnly::UpdateProperties(nsStyleContext* aStyleContext)
   if (aStyleContext->IsGecko()) {
 #ifdef MOZ_OLD_STYLE
     auto gecko = aStyleContext->AsGecko();
-    DoUpdateProperties(Move(gecko));
+    DoUpdateProperties(std::move(gecko));
     return;
 #else
     MOZ_CRASH("old style system disabled");
@@ -380,7 +380,7 @@ KeyframeEffectReadOnly::DoUpdateProperties(StyleType* aStyle)
     }
   }
 
-  mProperties = Move(properties);
+  mProperties = std::move(properties);
   UpdateEffectSet();
 
   for (AnimationProperty& property : mProperties) {
@@ -416,13 +416,13 @@ KeyframeEffectReadOnly::CompositeValue(
       StyleAnimationValue result(aValueToComposite);
       return StyleAnimationValue::Add(aProperty,
                                       aUnderlyingValue,
-                                      Move(result));
+                                      std::move(result));
     }
     case dom::CompositeOperation::Accumulate: {
       StyleAnimationValue result(aValueToComposite);
       return StyleAnimationValue::Accumulate(aProperty,
                                              aUnderlyingValue,
-                                             Move(result));
+                                             std::move(result));
     }
     default:
       MOZ_ASSERT_UNREACHABLE("Unknown compisite operation type");
@@ -649,21 +649,21 @@ KeyframeEffectReadOnly::ComposeStyleRule(
     fromValue =
       StyleAnimationValue::Accumulate(aProperty.mProperty,
                                       lastValue,
-                                      Move(fromValue),
+                                      std::move(fromValue),
                                       aComputedTiming.mCurrentIteration);
     toValue =
       StyleAnimationValue::Accumulate(aProperty.mProperty,
                                       lastValue,
-                                      Move(toValue),
+                                      std::move(toValue),
                                       aComputedTiming.mCurrentIteration);
   }
 
   // Special handling for zero-length segments
   if (aSegment.mToKey == aSegment.mFromKey) {
     if (aComputedTiming.mProgress.Value() < 0) {
-      aStyleRule->AddValue(aProperty.mProperty, Move(fromValue));
+      aStyleRule->AddValue(aProperty.mProperty, std::move(fromValue));
     } else {
-      aStyleRule->AddValue(aProperty.mProperty, Move(toValue));
+      aStyleRule->AddValue(aProperty.mProperty, std::move(toValue));
     }
     return;
   }
@@ -683,11 +683,11 @@ KeyframeEffectReadOnly::ComposeStyleRule(
                                        fromValue,
                                        toValue,
                                        valuePosition, val)) {
-    aStyleRule->AddValue(aProperty.mProperty, Move(val));
+    aStyleRule->AddValue(aProperty.mProperty, std::move(val));
   } else if (valuePosition < 0.5) {
-    aStyleRule->AddValue(aProperty.mProperty, Move(fromValue));
+    aStyleRule->AddValue(aProperty.mProperty, std::move(fromValue));
   } else {
-    aStyleRule->AddValue(aProperty.mProperty, Move(toValue));
+    aStyleRule->AddValue(aProperty.mProperty, std::move(toValue));
   }
 }
 #endif
@@ -1392,7 +1392,7 @@ KeyframeEffectReadOnly::GetKeyframes(JSContext*& aCx,
             DebugOnly<bool> uncomputeResult =
               StyleAnimationValue::UncomputeValue(
                 propertyValue.mProperty,
-                Move(BaseStyle(propertyValue.mProperty).mGecko),
+                std::move(BaseStyle(propertyValue.mProperty).mGecko),
                 cssValue);
 
             MOZ_ASSERT(uncomputeResult,
