@@ -699,7 +699,7 @@ ConvertKeyframeSequence(JSContext* aCx,
       if (!valuePair) {
         continue;
       }
-      keyframe->mPropertyValues.AppendElement(Move(valuePair.ref()));
+      keyframe->mPropertyValues.AppendElement(std::move(valuePair.ref()));
 
 #ifdef DEBUG
       // When we go to convert keyframes into arrays of property values we
@@ -894,7 +894,7 @@ MakePropertyValuePair(nsCSSPropertyID aProperty, const nsAString& aStringValue,
       ServoCSSParser::ParseProperty(aProperty, aStringValue, env);
 
     if (servoDeclarationBlock) {
-      result.emplace(aProperty, Move(servoDeclarationBlock));
+      result.emplace(aProperty, std::move(servoDeclarationBlock));
     } else {
       ReportInvalidPropertyValueToConsole(aProperty, aStringValue, aDocument);
     }
@@ -939,7 +939,7 @@ MakePropertyValuePair(nsCSSPropertyID aProperty, const nsAString& aStringValue,
     value.SetTokenStreamValue(tokenStream);
   }
 
-  result.emplace(aProperty, Move(value));
+  result.emplace(aProperty, std::move(value));
   return result;
 #else
   MOZ_CRASH("old style system disabled");
@@ -1086,7 +1086,7 @@ GetComputedKeyframeValues(const nsTArray<Keyframe>& aKeyframes,
           continue;
         }
         propertiesOnThisKeyframe.AddProperty(value.mProperty);
-        computedValues->AppendElement(Move(value));
+        computedValues->AppendElement(std::move(value));
       }
     }
   }
@@ -1450,13 +1450,13 @@ GetKeyframeListFromPropertyIndexedKeyframe(JSContext* aCx,
       if (!valuePair) {
         continue;
       }
-      keyframe->mPropertyValues.AppendElement(Move(valuePair.ref()));
+      keyframe->mPropertyValues.AppendElement(std::move(valuePair.ref()));
     }
   }
 
   aResult.SetCapacity(processedKeyframes.Count());
   for (auto iter = processedKeyframes.Iter(); !iter.Done(); iter.Next()) {
-    aResult.AppendElement(Move(*iter.UserData()));
+    aResult.AppendElement(std::move(*iter.UserData()));
   }
 
   aResult.Sort(ComputedOffsetComparator());
@@ -1519,7 +1519,7 @@ GetKeyframeListFromPropertyIndexedKeyframe(JSContext* aCx,
   auto parseAndAppendEasing = [&](const nsString& easingString,
                                   ErrorResult& aRv) {
     auto easing = TimingParams::ParseEasing(easingString, aDocument, aRv);
-    if (!aRv.Failed() && !easings.AppendElement(Move(easing), fallible)) {
+    if (!aRv.Failed() && !easings.AppendElement(std::move(easing), fallible)) {
       aRv.Throw(NS_ERROR_OUT_OF_MEMORY);
     }
   };
