@@ -1537,7 +1537,7 @@ ChildRunnable::Run()
         return NS_OK;
       }
 
-      mPrincipalInfo = Move(principalInfo);
+      mPrincipalInfo = std::move(principalInfo);
 
       PBackgroundChild* actor = BackgroundChild::GetOrCreateForCurrentThread();
       if (NS_WARN_IF(!actor)) {
