@@ -1778,9 +1778,6 @@ Navigator::RequestMediaKeySystemAccess(const nsAString& aKeySystem,
             aKeySystem, aConfigs, mWindow->IsSecureContext())
             .get());
 
-  Telemetry::Accumulate(Telemetry::MEDIA_EME_SECURE_CONTEXT,
-                        mWindow->IsSecureContext());
-
   if (!mWindow->IsSecureContext()) {
     nsIDocument* doc = mWindow->GetExtantDoc();
     nsString uri;
