@@ -547,7 +547,7 @@ nsAttrValue::ToString(mozilla::dom::DOMString& aResult) const
     case eAtom:
     {
       nsIAtom *atom = static_cast<nsIAtom*>(GetPtr());
-      aResult.SetStringBuffer(atom->GetStringBuffer(), atom->GetLength());
+      aResult.SetOwnedAtom(atom, mozilla::dom::DOMString::eNullNotExpected);
       break;
     }
     default:
