@@ -274,8 +274,7 @@ nsAttributeTextNode::UnbindFromTree(bool aDeep, bool aNullParent)
 }
 
 void
-nsAttributeTextNode::AttributeChanged(nsIDocument* aDocument,
-                                      Element* aElement,
+nsAttributeTextNode::AttributeChanged(Element* aElement,
                                       int32_t aNameSpaceID,
                                       nsIAtom* aAttribute,
                                       int32_t aModType,
