@@ -85,6 +85,11 @@ class MOZ_STACK_CLASS nsTreeSanitizer {
      */
     bool mFullDocument;
 
+    /**
+     * Whether we should notify to the console for anything that's stripped.
+     */
+    bool mLogRemovals;
+
     void SanitizeChildren(nsINode* aRoot);
 
     /**
@@ -188,6 +193,20 @@ class MOZ_STACK_CLASS nsTreeSanitizer {
      */
     void RemoveAllAttributesFromDescendants(mozilla::dom::Element* aElement);
 
+    /**
+     * Log a Console Service message to indicate we removed something.
+     * If you pass an element and/or attribute, their information will
+     * be appended to the message.
+     *
+     * @param aMessage   the basic message to log.
+     * @param aDocument  the base document we're modifying
+     *                   (used for the error message)
+     * @param aElement   optional, the element being removed or modified.
+     * @param aAttribute optional, the attribute being removed or modified.
+     */
+    void LogMessage(const char* aMessage, nsIDocument* aDoc,
+                    Element* aElement = nullptr, nsIAtom* aAttr = nullptr);
+
     /**
      * The whitelist of HTML elements.
      */
