@@ -109,7 +109,7 @@ CanvasRenderingContextHelper::ToBlob(JSContext* aCx,
   aRv = ImageEncoder::ExtractDataAsync(type,
                                        params,
                                        usingCustomParseOptions,
-                                       Move(imageBuffer),
+                                       std::move(imageBuffer),
                                        format,
                                        GetWidthHeight(),
                                        callback);
