@@ -518,7 +518,7 @@ WebGLContext::DrawArrays_check(const char* const funcName, const GLint first,
 }
 
 void
-WebGLContext::DrawArraysInstanced(GLenum mode, GLint first, GLsizei vertCount,
+WebGLContext::DrawArraysInstanced(GLenum mode, GLint first, GLsizei iVertCount,
                                   GLsizei instanceCount, const char* const funcName)
 {
     AUTO_PROFILER_LABEL("WebGLContext::DrawArraysInstanced", GRAPHICS);
@@ -527,10 +527,20 @@ WebGLContext::DrawArraysInstanced(GLenum mode, GLint first, GLsizei vertCount,
 
     const gl::GLContext::TlsScope inTls(gl);
 
+    const auto vertCount = AssertedCast<uint32_t>(iVertCount);
+
     Maybe<uint32_t> lastVert;
     if (!DrawArrays_check(funcName, first, vertCount, instanceCount, &lastVert))
         return;
 
+    if (vertCount > mMaxVertIdsPerDraw) {
+      ErrorOutOfMemory(
+          "Context's max vertCount is %u, but %u requested. "
+          "[webgl.max-vert-ids-per-draw]",
+          mMaxVertIdsPerDraw, vertCount);
+      return;
+    }
+
     bool error = false;
     const ScopedDrawHelper scopedHelper(this, funcName, mode, lastVert, instanceCount,
                                         &error);
@@ -674,11 +684,12 @@ HandleDrawElementsErrors(WebGLContext* webgl, const char* funcName,
     }
 }
 
-void
-WebGLContext::DrawElementsInstanced(GLenum mode, GLsizei indexCount, GLenum type,
-                                    WebGLintptr byteOffset, GLsizei instanceCount,
-                                    const char* const funcName)
-{
+void WebGLContext::DrawElementsInstanced(const GLenum mode,
+                                         const GLsizei iIndexCount,
+                                         const GLenum type,
+                                         const WebGLintptr byteOffset,
+                                         const GLsizei instanceCount,
+                                         const char* const funcName) {
     AUTO_PROFILER_LABEL("WebGLContext::DrawElementsInstanced", GRAPHICS);
     if (IsContextLost())
         return;
@@ -686,11 +697,20 @@ WebGLContext::DrawElementsInstanced(GLenum mode, GLsizei indexCount, GLenum type
     const gl::GLContext::TlsScope inTls(gl);
 
     Maybe<uint32_t> lastVert;
-    if (!DrawElements_check(funcName, indexCount, type, byteOffset, instanceCount,
+    if (!DrawElements_check(funcName, iIndexCount, type, byteOffset, instanceCount,
                             &lastVert))
     {
         return;
     }
+    const auto indexCount = AssertedCast<uint32_t>(iIndexCount);
+
+    if (indexCount > mMaxVertIdsPerDraw) {
+      ErrorOutOfMemory(
+          "Context's max indexCount is %u, but %u requested. "
+          "[webgl.max-vert-ids-per-draw]",
+          mMaxVertIdsPerDraw, indexCount);
+      return;
+    }
 
     bool error = false;
     const ScopedDrawHelper scopedHelper(this, funcName, mode, lastVert, instanceCount,
