@@ -16,8 +16,8 @@
 #include "nsIDocument.h"
 #include "nsIPresShell.h"
 #include "nsIScrollableFrame.h"
+#include "nsITextControlElement.h"
 #include "nsITimer.h"
-#include "nsPluginFrame.h"
 #include "nsPresContext.h"
 #include "prtime.h"
 #include "Units.h"
@@ -52,11 +52,10 @@ WheelHandlingUtils::CanScrollOn(nsIFrame* aFrame,
                                 double aDirectionX, double aDirectionY)
 {
   nsIScrollableFrame* scrollableFrame = do_QueryFrame(aFrame);
-  if (scrollableFrame) {
-    return CanScrollOn(scrollableFrame, aDirectionX, aDirectionY);
+  if (!scrollableFrame) {
+    return false;
   }
-  nsPluginFrame* pluginFrame = do_QueryFrame(aFrame);
-  return pluginFrame && pluginFrame->WantsToHandleWheelEventAsDefaultAction();
+  return CanScrollOn(scrollableFrame, aDirectionX, aDirectionY);
 }
 
 /* static */ bool
@@ -79,6 +78,31 @@ WheelHandlingUtils::CanScrollOn(nsIScrollableFrame* aScrollFrame,
                            scrollRange.YMost(), aDirectionY));
 }
 
+/*static*/ Maybe<layers::ScrollDirection>
+WheelHandlingUtils::GetDisregardedWheelScrollDirection(const nsIFrame* aFrame)
+{
+  nsIContent* content = aFrame->GetContent();
+  if (!content) {
+    return Nothing();
+  }
+  nsCOMPtr<nsITextControlElement> ctrl =
+    do_QueryInterface(content->IsInAnonymousSubtree()
+                      ? content->GetBindingParent() : content);
+  if (!ctrl || !ctrl->IsSingleLineTextControl()) {
+    return Nothing();
+  }
+  // Disregard scroll in the block-flow direction by mouse wheel on a
+  // single-line text control. For instance, in tranditional Chinese writing
+  // system, a single-line text control cannot be scrolled horizontally with
+  // mouse wheel even if they overflow at the right and left edges; Whereas in
+  // latin-based writing system, a single-line text control cannot be scrolled
+  // vertically with mouse wheel even if they overflow at the top and bottom
+  // edges
+  return Some(aFrame->GetWritingMode().IsVertical()
+              ? layers::ScrollDirection::eHorizontal
+              : layers::ScrollDirection::eVertical);
+}
+
 /******************************************************************/
 /* mozilla::WheelTransaction                                      */
 /******************************************************************/
@@ -105,7 +129,7 @@ WheelTransaction::OwnScrollbars(bool aOwn)
 
 /* static */ void
 WheelTransaction::BeginTransaction(nsIFrame* aTargetFrame,
-                                   WidgetWheelEvent* aEvent)
+                                   const WidgetWheelEvent* aEvent)
 {
   NS_ASSERTION(!sTargetFrame, "previous transaction is not finished!");
   MOZ_ASSERT(aEvent->mMessage == eWheel,
@@ -120,7 +144,7 @@ WheelTransaction::BeginTransaction(nsIFrame* aTargetFrame,
 }
 
 /* static */ bool
-WheelTransaction::UpdateTransaction(WidgetWheelEvent* aEvent)
+WheelTransaction::UpdateTransaction(const WidgetWheelEvent* aEvent)
 {
   nsIFrame* scrollToFrame = GetTargetFrame();
   nsIScrollableFrame* scrollableFrame = scrollToFrame->GetScrollTargetFrame();
@@ -324,11 +348,10 @@ WheelTransaction::OnTimeout(nsITimer* aTimer, void* aClosure)
 WheelTransaction::SetTimeout()
 {
   if (!sTimer) {
-    nsCOMPtr<nsITimer> timer = do_CreateInstance(NS_TIMER_CONTRACTID);
-    if (!timer) {
+    sTimer = NS_NewTimer().take();
+    if (!sTimer) {
       return;
     }
-    timer.swap(sTimer);
   }
   sTimer->Cancel();
   DebugOnly<nsresult> rv =
@@ -530,8 +553,9 @@ ScrollbarsForWheel::DeactivateAllTemporarilyActivatedScrollTargets()
 }
 
 /******************************************************************/
-/* mozilla::WheelTransaction                                      */
+/* mozilla::WheelTransaction::Prefs                               */
 /******************************************************************/
+
 int32_t WheelTransaction::Prefs::sMouseWheelAccelerationStart = -1;
 int32_t WheelTransaction::Prefs::sMouseWheelAccelerationFactor = -1;
 uint32_t WheelTransaction::Prefs::sMouseWheelTransactionTimeout = 1500;
@@ -556,4 +580,47 @@ WheelTransaction::Prefs::InitializeStatics()
   }
 }
 
+/******************************************************************/
+/* mozilla::AutoWheelDeltaAdjuster                                */
+/******************************************************************/
+
+AutoWheelDeltaAdjuster::AutoWheelDeltaAdjuster(WidgetWheelEvent& aWheelEvent)
+  : mWheelEvent(aWheelEvent)
+  , mOldDeltaX(aWheelEvent.mDeltaX)
+  , mOldDeltaZ(aWheelEvent.mDeltaZ)
+  , mOldOverflowDeltaX(aWheelEvent.mOverflowDeltaX)
+  , mOldLineOrPageDeltaX(aWheelEvent.mLineOrPageDeltaX)
+  , mTreatedVerticalWheelAsHorizontalScroll(false)
+{
+  MOZ_ASSERT(!aWheelEvent.mDeltaValuesAdjustedForDefaultHandler);
+
+  if (EventStateManager::WheelEventIsHorizontalScrollAction(&aWheelEvent)) {
+    // Move deltaY values to deltaX and set both deltaY and deltaZ to 0.
+    mWheelEvent.mDeltaX = mWheelEvent.mDeltaY;
+    mWheelEvent.mDeltaY = 0.0;
+    mWheelEvent.mDeltaZ = 0.0;
+    mWheelEvent.mOverflowDeltaX = mWheelEvent.mOverflowDeltaY;
+    mWheelEvent.mOverflowDeltaY = 0.0;
+    mWheelEvent.mLineOrPageDeltaX = mWheelEvent.mLineOrPageDeltaY;
+    mWheelEvent.mLineOrPageDeltaY = 0;
+    mWheelEvent.mDeltaValuesAdjustedForDefaultHandler = true;
+    mTreatedVerticalWheelAsHorizontalScroll = true;
+  }
+}
+
+AutoWheelDeltaAdjuster::~AutoWheelDeltaAdjuster()
+{
+  if (mTreatedVerticalWheelAsHorizontalScroll &&
+      mWheelEvent.mDeltaValuesAdjustedForDefaultHandler) {
+    mWheelEvent.mDeltaY = mWheelEvent.mDeltaX;
+    mWheelEvent.mDeltaX = mOldDeltaX;
+    mWheelEvent.mDeltaZ = mOldDeltaZ;
+    mWheelEvent.mOverflowDeltaY = mWheelEvent.mOverflowDeltaX;
+    mWheelEvent.mOverflowDeltaX = mOldOverflowDeltaX;
+    mWheelEvent.mLineOrPageDeltaY = mWheelEvent.mLineOrPageDeltaX;
+    mWheelEvent.mLineOrPageDeltaX = mOldLineOrPageDeltaX;
+    mWheelEvent.mDeltaValuesAdjustedForDefaultHandler = false;
+  }
+}
+
 } // namespace mozilla
