@@ -1,3 +1,8 @@
+/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* vim: set ts=8 sts=2 et sw=2 tw=80: */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #ifndef mozilla_dom_gamepad_GamepadPoseState_h_
 #define mozilla_dom_gamepad_GamepadPoseState_h_
@@ -46,8 +51,16 @@ struct GamepadPoseState
   bool isOrientationValid;
 
   GamepadPoseState()
+    : flags(GamepadCapabilityFlags::Cap_None)
+    , orientation{ 0, 0, 0, 0 }
+    , position{ 0, 0, 0}
+    , angularVelocity{ 0, 0, 0}
+    , angularAcceleration{ 0, 0, 0}
+    , linearVelocity{ 0, 0, 0}
+    , linearAcceleration{ 0, 0, 0}
+    , isPositionValid(false)
+    , isOrientationValid(false)
   {
-    Clear();
   }
 
   bool operator==(const GamepadPoseState& aPose) const
@@ -82,11 +95,14 @@ struct GamepadPoseState
   }
 
   void Clear() {
-    memset(this, 0, sizeof(GamepadPoseState));
+    memset(&flags,
+           0,
+           reinterpret_cast<char*>(&isOrientationValid) +
+             sizeof(isOrientationValid) - reinterpret_cast<char*>(&flags));
   }
 };
 
 }// namespace dom
 }// namespace mozilla
 
-#endif // mozilla_dom_gamepad_GamepadPoseState_h_
\ No newline at end of file
+#endif // mozilla_dom_gamepad_GamepadPoseState_h_
