@@ -10,7 +10,6 @@
 #include "mozilla/dom/ElementInlines.h"
 
 #include "nsIDocument.h"
-#include "nsIPluginDocument.h"
 #include "nsIDOMDocument.h"
 #include "nsThreadUtils.h"
 #include "nsIScriptError.h"
@@ -41,9 +40,6 @@ HTMLEmbedElement::HTMLEmbedElement(already_AddRefed<mozilla::dom::NodeInfo>& aNo
 
 HTMLEmbedElement::~HTMLEmbedElement()
 {
-#ifdef XP_MACOSX
-  HTMLObjectElement::OnFocusBlurPlugin(this, false);
-#endif
   UnregisterActivityObserver();
   DestroyImageLoadingContent();
 }
@@ -55,36 +51,18 @@ NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN_INHERITED(HTMLEmbedElement,
 nsObjectLoadingContent::Traverse(tmp, cb);
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
 
-NS_IMPL_ADDREF_INHERITED(HTMLEmbedElement, Element)
-NS_IMPL_RELEASE_INHERITED(HTMLEmbedElement, Element)
-
-NS_INTERFACE_TABLE_HEAD_CYCLE_COLLECTION_INHERITED(HTMLEmbedElement)
-NS_INTERFACE_TABLE_INHERITED(HTMLEmbedElement,
-                             nsIRequestObserver,
-                             nsIStreamListener,
-                             nsIFrameLoaderOwner,
-                             nsIObjectLoadingContent,
-                             imgINotificationObserver,
-                             nsIImageLoadingContent,
-                             imgIOnloadBlocker,
-                             nsIChannelEventSink)
-NS_INTERFACE_TABLE_TO_MAP_SEGUE
-  NS_INTERFACE_MAP_ENTRY(nsIDOMHTMLEmbedElement)
-NS_INTERFACE_MAP_END_INHERITING(nsGenericHTMLElement)
+NS_IMPL_ISUPPORTS_CYCLE_COLLECTION_INHERITED(HTMLEmbedElement,
+                                             nsGenericHTMLElement,
+                                             nsIRequestObserver,
+                                             nsIStreamListener,
+                                             nsIFrameLoaderOwner,
+                                             nsIObjectLoadingContent,
+                                             imgINotificationObserver,
+                                             nsIImageLoadingContent,
+                                             nsIChannelEventSink)
 
 NS_IMPL_ELEMENT_CLONE(HTMLEmbedElement)
 
-#ifdef XP_MACOSX
-
-NS_IMETHODIMP
-HTMLEmbedElement::PostHandleEvent(EventChainPostVisitor& aVisitor)
-{
-  HTMLObjectElement::HandleFocusBlurPlugin(this, aVisitor.mEvent);
-  return NS_OK;
-}
-
-#endif // #ifdef XP_MACOSX
-
 void
 HTMLEmbedElement::AsyncEventRunning(AsyncEventDispatcher* aEvent)
 {
@@ -107,17 +85,9 @@ HTMLEmbedElement::BindToTree(nsIDocument *aDocument,
                                           aCompileEventHandlers);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  // Don't kick off load from being bound to a plugin document - the plugin
-  // document will call nsObjectLoadingContent::InitializeFromChannel() for the
-  // initial load.
-  nsCOMPtr<nsIPluginDocument> pluginDoc = do_QueryInterface(aDocument);
-
-  if (!pluginDoc) {
-    void (HTMLEmbedElement::*start)() = &HTMLEmbedElement::StartObjectLoad;
-    nsContentUtils::AddScriptRunner(NewRunnableMethod(
-                                      "dom::HTMLEmbedElement::BindToTree", this, start));
-  }
-
+  void (HTMLEmbedElement::*start)() = &HTMLEmbedElement::StartObjectLoad;
+  nsContentUtils::AddScriptRunner(
+      NewRunnableMethod("dom::HTMLEmbedElement::BindToTree", this, start));
   return NS_OK;
 }
 
@@ -125,14 +95,6 @@ void
 HTMLEmbedElement::UnbindFromTree(bool aDeep,
                                  bool aNullParent)
 {
-#ifdef XP_MACOSX
-  // When a page is reloaded (when an nsIDocument's content is removed), the
-  // focused element isn't necessarily sent an eBlur event. See
-  // nsFocusManager::ContentRemoved(). This means that a widget may think it
-  // still contains a focused plugin when it doesn't -- which in turn can
-  // disable text input in the browser window. See bug 1137229.
-  HTMLObjectElement::OnFocusBlurPlugin(this, false);
-#endif
   nsObjectLoadingContent::UnbindFromTree(aDeep, aNullParent);
   nsGenericHTMLElement::UnbindFromTree(aDeep, aNullParent);
 }
@@ -141,6 +103,7 @@ nsresult
 HTMLEmbedElement::AfterSetAttr(int32_t aNamespaceID, nsIAtom* aName,
                                const nsAttrValue* aValue,
                                const nsAttrValue* aOldValue,
+                               nsIPrincipal* aSubjectPrincipal,
                                bool aNotify)
 {
   if (aValue) {
@@ -149,7 +112,7 @@ HTMLEmbedElement::AfterSetAttr(int32_t aNamespaceID, nsIAtom* aName,
   }
 
   return nsGenericHTMLElement::AfterSetAttr(aNamespaceID, aName, aValue,
-                                            aOldValue, aNotify);
+                                            aOldValue, aSubjectPrincipal, aNotify);
 }
 
 nsresult
@@ -200,7 +163,17 @@ HTMLEmbedElement::IsHTMLFocusable(bool aWithMouse,
                                   bool *aIsFocusable,
                                   int32_t *aTabIndex)
 {
-  // Has plugin content: let the plugin decide what to do in terms of
+  // Plugins that show the empty fallback should not accept focus.
+  if (Type() == eType_Fallback) {
+    if (aTabIndex) {
+      *aTabIndex = -1;
+    }
+
+    *aIsFocusable = false;
+    return false;
+  }
+
+  // Has non-plugin content: let the plugin decide what to do in terms of
   // internal focus from mouse clicks
   if (aTabIndex) {
     *aTabIndex = TabIndex();
@@ -212,16 +185,6 @@ HTMLEmbedElement::IsHTMLFocusable(bool aWithMouse,
   return true;
 }
 
-nsIContent::IMEState
-HTMLEmbedElement::GetDesiredIMEState()
-{
-  if (Type() == eType_Plugin) {
-    return IMEState(IMEState::PLUGIN);
-  }
-
-  return nsGenericHTMLElement::GetDesiredIMEState();
-}
-
 int32_t
 HTMLEmbedElement::TabIndexDefault()
 {
@@ -232,6 +195,7 @@ bool
 HTMLEmbedElement::ParseAttribute(int32_t aNamespaceID,
                                  nsIAtom *aAttribute,
                                  const nsAString &aValue,
+                                 nsIPrincipal* aMaybeScriptedPrincipal,
                                  nsAttrValue &aResult)
 {
   if (aNamespaceID == kNameSpaceID_None) {
@@ -244,7 +208,7 @@ HTMLEmbedElement::ParseAttribute(int32_t aNamespaceID,
   }
 
   return nsGenericHTMLElement::ParseAttribute(aNamespaceID, aAttribute, aValue,
-                                              aResult);
+                                              aMaybeScriptedPrincipal, aResult);
 }
 
 static void
@@ -342,15 +306,7 @@ HTMLEmbedElement::CopyInnerTo(Element* aDest, bool aPreallocateChildren)
 JSObject*
 HTMLEmbedElement::WrapNode(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
 {
-  JSObject* obj;
-  obj = HTMLEmbedElementBinding::Wrap(aCx, this, aGivenProto);
-
-  if (!obj) {
-    return nullptr;
-  }
-  JS::Rooted<JSObject*> rootedObj(aCx, obj);
-  SetupProtoChain(aCx, rootedObj);
-  return rootedObj;
+  return HTMLEmbedElementBinding::Wrap(aCx, this, aGivenProto);
 }
 
 nsContentPolicyType
@@ -359,12 +315,5 @@ HTMLEmbedElement::GetContentPolicyType() const
   return nsIContentPolicy::TYPE_INTERNAL_EMBED;
 }
 
-NS_IMPL_STRING_ATTR(HTMLEmbedElement, Align, align)
-NS_IMPL_STRING_ATTR(HTMLEmbedElement, Width, width)
-NS_IMPL_STRING_ATTR(HTMLEmbedElement, Height, height)
-NS_IMPL_STRING_ATTR(HTMLEmbedElement, Name, name)
-NS_IMPL_URI_ATTR(HTMLEmbedElement, Src, src)
-NS_IMPL_STRING_ATTR(HTMLEmbedElement, Type, type)
-
 } // namespace dom
 } // namespace mozilla
