@@ -94,6 +94,7 @@ public:
   virtual bool ParseAttribute(int32_t aNamespaceID,
                                 nsIAtom* aAttribute,
                                 const nsAString& aValue,
+                                nsIPrincipal* aMaybeScriptedPrincipal,
                                 nsAttrValue& aResult) override;
   virtual nsresult GetEventTargetParent(
                      EventChainPreVisitor& aVisitor) override;
@@ -113,6 +114,7 @@ public:
   virtual nsresult AfterSetAttr(int32_t aNameSpaceID, nsIAtom* aName,
                                 const nsAttrValue* aValue,
                                 const nsAttrValue* aOldValue,
+                                nsIPrincipal* aSubjectPrincipal,
                                 bool aNotify) override;
 
   /**
@@ -220,6 +222,12 @@ public:
     */
   bool ImplicitSubmissionIsDisabled() const;
 
+  /**
+  * Check whether a given nsIFormControl is the last single line input control
+  * that is not disabled. aControl is expected to not be null.
+  */
+  bool IsLastActiveElement(const nsIFormControl* aControl) const;
+
   /**
    * Check whether a given nsIFormControl is the default submit
    * element.  This is different from just comparing to
@@ -234,7 +242,7 @@ public:
    * submission. In that case the form will defer the submission until the
    * script handler returns and the return value is known.
    */
-  void OnSubmitClickBegin(nsIContent* aOriginatingElement);
+  void OnSubmitClickBegin(Element* aOriginatingElement);
   void OnSubmitClickEnd();
 
   /**
@@ -552,7 +560,7 @@ public:
    * @param aActionURL the full, unadulterated URL you'll be submitting to [OUT]
    * @param aOriginatingElement the originating element of the form submission [IN]
    */
-  nsresult GetActionURL(nsIURI** aActionURL, nsIContent* aOriginatingElement);
+  nsresult GetActionURL(nsIURI** aActionURL, Element* aOriginatingElement);
 protected:
 
   //
