@@ -11,7 +11,9 @@
 #include "nsGenericHTMLElement.h"
 #include "nsMappedAttributes.h"
 #include "nsAttrValueInlines.h"
+#ifdef MOZ_OLD_STYLE
 #include "nsRuleData.h"
+#endif
 
 namespace mozilla {
 namespace dom {
