@@ -12,6 +12,7 @@
 #include "mozilla/MouseEvents.h"
 #include "mozilla/dom/HTMLLabelElementBinding.h"
 #include "nsFocusManager.h"
+#include "nsContentUtils.h"
 #include "nsIDOMMouseEvent.h"
 #include "nsQueryObject.h"
 #include "mozilla/dom/ShadowRoot.h"
@@ -35,46 +36,12 @@ HTMLLabelElement::WrapNode(JSContext *aCx, JS::Handle<JSObject*> aGivenProto)
 
 // nsISupports
 
-NS_IMPL_ISUPPORTS_INHERITED(HTMLLabelElement, nsGenericHTMLElement,
-                            nsIDOMHTMLLabelElement)
+NS_IMPL_ISUPPORTS_INHERITED0(HTMLLabelElement, nsGenericHTMLElement)
 
 // nsIDOMHTMLLabelElement
 
 NS_IMPL_ELEMENT_CLONE(HTMLLabelElement)
 
-NS_IMETHODIMP
-HTMLLabelElement::GetForm(nsIDOMHTMLFormElement** aForm)
-{
-  RefPtr<nsIDOMHTMLFormElement> form = GetForm();
-  form.forget(aForm);
-  return NS_OK;
-}
-
-NS_IMETHODIMP
-HTMLLabelElement::GetControl(nsIDOMHTMLElement** aElement)
-{
-  nsCOMPtr<nsIDOMHTMLElement> element = do_QueryObject(GetLabeledElement());
-  element.forget(aElement);
-  return NS_OK;
-}
-
-NS_IMETHODIMP
-HTMLLabelElement::SetHtmlFor(const nsAString& aHtmlFor)
-{
-  ErrorResult rv;
-  SetHtmlFor(aHtmlFor, rv);
-  return rv.StealNSResult();
-}
-
-NS_IMETHODIMP
-HTMLLabelElement::GetHtmlFor(nsAString& aHtmlFor)
-{
-  nsString htmlFor;
-  GetHtmlFor(htmlFor);
-  aHtmlFor = htmlFor;
-  return NS_OK;
-}
-
 HTMLFormElement*
 HTMLLabelElement::GetForm() const
 {
@@ -271,19 +238,14 @@ HTMLLabelElement::GetLabeledElement() const
 
   // We have a @for. The id has to be linked to an element in the same tree
   // and this element should be a labelable form control.
-  nsINode* root = SubtreeRoot();
-  ShadowRoot* shadow = ShadowRoot::FromNode(root);
   Element* element = nullptr;
 
-  if (shadow) {
-    element = shadow->GetElementById(elementId);
+  if (ShadowRoot* shadowRoot = GetContainingShadow()) {
+    element = shadowRoot->GetElementById(elementId);
+  } else if (nsIDocument* doc = GetUncomposedDoc()) {
+    element = doc->GetElementById(elementId);
   } else {
-    nsIDocument* doc = GetUncomposedDoc();
-    if (doc) {
-      element = doc->GetElementById(elementId);
-    } else {
-      element = nsContentUtils::MatchElementId(root->AsContent(), elementId);
-    }
+    element = nsContentUtils::MatchElementId(SubtreeRoot()->AsContent(), elementId);
   }
 
   if (element && element->IsLabelable()) {
