@@ -23,6 +23,8 @@
 #include "mozilla/dom/ErrorEventBinding.h"
 #include "mozilla/dom/IDBOpenDBRequestBinding.h"
 #include "mozilla/dom/ScriptSettings.h"
+#include "mozilla/dom/WorkerHolder.h"
+#include "mozilla/dom/WorkerPrivate.h"
 #include "nsCOMPtr.h"
 #include "nsContentUtils.h"
 #include "nsIScriptContext.h"
@@ -30,8 +32,6 @@
 #include "nsPIDOMWindow.h"
 #include "nsString.h"
 #include "ReportInternalError.h"
-#include "WorkerHolder.h"
-#include "WorkerPrivate.h"
 
 // Include this last to avoid path problems on Windows.
 #include "ActorsChild.h"
@@ -40,7 +40,6 @@ namespace mozilla {
 namespace dom {
 
 using namespace mozilla::dom::indexedDB;
-using namespace mozilla::dom::workers;
 using namespace mozilla::ipc;
 
 namespace {
@@ -416,7 +415,7 @@ IDBRequest::GetEventTargetParent(EventChainPreVisitor& aVisitor)
 }
 
 class IDBOpenDBRequest::WorkerHolder final
-  : public mozilla::dom::workers::WorkerHolder
+  : public mozilla::dom::WorkerHolder
 {
   WorkerPrivate* mWorkerPrivate;
 #ifdef DEBUG
@@ -428,7 +427,7 @@ class IDBOpenDBRequest::WorkerHolder final
 public:
   explicit
   WorkerHolder(WorkerPrivate* aWorkerPrivate)
-    : mozilla::dom::workers::WorkerHolder("IDBOpenDBRequest::WorkerHolder")
+    : mozilla::dom::WorkerHolder("IDBOpenDBRequest::WorkerHolder")
     , mWorkerPrivate(aWorkerPrivate)
 #ifdef DEBUG
     , mWorkerPrivateDEBUG(aWorkerPrivate)
@@ -460,7 +459,7 @@ public:
 
 private:
   virtual bool
-  Notify(Status aStatus) override;
+  Notify(WorkerStatus aStatus) override;
 };
 
 IDBOpenDBRequest::IDBOpenDBRequest(IDBFactory* aFactory,
@@ -538,7 +537,7 @@ IDBOpenDBRequest::CreateForJS(JSContext* aCx,
       return nullptr;
     }
 
-    request->mWorkerHolder = Move(workerHolder);
+    request->mWorkerHolder = std::move(workerHolder);
   }
 
   request->IncreaseActiveDatabaseCount();
@@ -664,7 +663,7 @@ IDBOpenDBRequest::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
 
 bool
 IDBOpenDBRequest::
-WorkerHolder::Notify(Status aStatus)
+WorkerHolder::Notify(WorkerStatus aStatus)
 {
   MOZ_ASSERT(mWorkerPrivate);
   mWorkerPrivate->AssertIsOnWorkerThread();
