@@ -28,7 +28,7 @@ ReportInternalError(const char* aFile, uint32_t aLine, const char* aStr)
   nsContentUtils::LogSimpleConsoleError(
     NS_ConvertUTF8toUTF16(nsPrintfCString(
                           "IndexedDB %s: %s:%" PRIu32, aStr, aFile, aLine)),
-    "indexedDB");
+    "indexedDB", false /* no IDB in private window */);
 }
 
 } // namespace indexedDB
