@@ -209,11 +209,6 @@ ChannelMediaDecoder::Create(MediaDecoderInit& aInit,
     return decoder.forget();
   }
 
-  if (DecoderTraits::IsHttpLiveStreamingType(type)) {
-    // We don't have an HLS decoder.
-    Telemetry::Accumulate(Telemetry::MEDIA_HLS_DECODER_SUCCESS, false);
-  }
-
   return nullptr;
 }
 
