@@ -99,7 +99,7 @@ public:
   AlignedBuffer(AlignedBuffer&& aOther)
     : mData(aOther.mData)
     , mLength(aOther.mLength)
-    , mBuffer(Move(aOther.mBuffer))
+    , mBuffer(std::move(aOther.mBuffer))
     , mCapacity(aOther.mCapacity)
   {
     aOther.mData = nullptr;
@@ -109,8 +109,16 @@ public:
 
   AlignedBuffer& operator=(AlignedBuffer&& aOther)
   {
-    this->~AlignedBuffer();
-    new (this) AlignedBuffer(Move(aOther));
+    if (&aOther == this) {
+      return *this;
+    }
+    mData = aOther.mData;
+    mLength = aOther.mLength;
+    mBuffer = std::move(aOther.mBuffer);
+    mCapacity = aOther.mCapacity;
+    aOther.mData = nullptr;
+    aOther.mLength = 0;
+    aOther.mCapacity = 0;
     return *this;
   }
 
@@ -263,7 +271,7 @@ private:
       PodCopy(newData, mData, mLength);
     }
 
-    mBuffer = Move(newBuffer);
+    mBuffer = std::move(newBuffer);
     mCapacity = sizeNeeded.value();
     mData = newData;
 
@@ -401,7 +409,7 @@ public:
     , mChannels(aChannels)
     , mChannelMap(aChannelMap)
     , mRate(aRate)
-    , mAudioData(Move(aData))
+    , mAudioData(std::move(aData))
   {
   }
 
