@@ -286,7 +286,7 @@ class MediaRecorder::Session: public PrincipalChangeObserver<MediaStreamTrack>,
                                nsTArray<nsTArray<uint8_t>>&& aBuffer)
       : Runnable("StoreEncodedBufferRunnable")
       , mSession(aSession)
-      , mBuffer(Move(aBuffer))
+      , mBuffer(std::move(aBuffer))
     {}
 
     NS_IMETHOD
@@ -717,7 +717,7 @@ private:
 
     // Append pulled data into cache buffer.
     NS_DispatchToMainThread(new StoreEncodedBufferRunnable(this,
-                                                           Move(encodedBuf)));
+                                                           std::move(encodedBuf)));
 
     // Whether push encoded data back to onDataAvailable automatically or we
     // need a flush.
@@ -1057,7 +1057,7 @@ private:
 
     // Append pulled data into cache buffer.
     NS_DispatchToMainThread(new StoreEncodedBufferRunnable(this,
-                                                           Move(encodedBuf)));
+                                                           std::move(encodedBuf)));
 
     RefPtr<Session> self = this;
     NS_DispatchToMainThread(NewRunnableFrom([self, mime]() {
@@ -1157,7 +1157,7 @@ private:
     }
 
     {
-      auto tracks(Move(mMediaStreamTracks));
+      auto tracks(std::move(mMediaStreamTracks));
       for (RefPtr<MediaStreamTrack>& track : tracks) {
         track->RemovePrincipalChangeObserver(this);
       }
