@@ -18,6 +18,7 @@
 #include "mozilla/MozPromise.h"
 #include "mozilla/ReentrantMonitor.h"
 #include "mozilla/RefPtr.h"
+#include "mozilla/SharedThreadPool.h"
 #include "mozilla/UniquePtr.h"
 #include "nsAutoPtr.h"
 #include "nsCOMPtr.h"
@@ -185,20 +186,11 @@ private:
   const T mValue;
 };
 
-class SharedThreadPool;
-
-// The MediaDataDecoder API blocks, with implementations waiting on platform
-// decoder tasks.  These platform decoder tasks are queued on a separate
-// thread pool to ensure they can run when the MediaDataDecoder clients'
-// thread pool is blocked.  Tasks on the PLATFORM_DECODER thread pool must not
-// wait on tasks in the PLAYBACK thread pool.
-//
-// No new dependencies on this mechanism should be added, as methods are being
-// made async supported by MozPromise, making this unnecessary and
-// permitting unifying the pool.
 enum class MediaThreadType {
   PLAYBACK, // MediaDecoderStateMachine and MediaFormatReader
-  PLATFORM_DECODER
+  PLATFORM_DECODER, // MediaDataDecoder
+  MSG_CONTROL,
+  WEBRTC_DECODER
 };
 // Returns the thread pool that is shared amongst all decoder state machines
 // for decoding streams.
@@ -593,6 +585,15 @@ StringListContains(const ListString& aList, const ItemString& aItem)
   return false;
 }
 
+inline void
+AppendStringIfNotEmpty(nsACString& aDest, nsACString&& aSrc)
+{
+  if (!aSrc.IsEmpty()) {
+    aDest.Append(NS_LITERAL_CSTRING("\n"));
+    aDest.Append(aSrc);
+  }
+}
+
 } // end namespace mozilla
 
 #endif
