@@ -13,6 +13,7 @@
 #include "mozilla/Atomics.h"
 #include "mozilla/DefineEnum.h"
 #include "mozilla/MozPromise.h"
+#include "mozilla/NonDereferenceable.h"
 #include "nsString.h"
 
 namespace mozilla {
@@ -102,56 +103,29 @@ public:
                   Forward<Value>(aValue));
   }
 
-  // LogValue with a string literal, as they are not seen as `const char*` by
-  // Variant. Also, a literal doesn't have runtime costs, so it's cheap to call
-  // directly.
-  template<size_t N>
-  static void LogValue(const char* aSubjectTypeName,
-                       const void* aSubjectPointer,
-                       DDLogCategory aCategory,
-                       const char* aLabel,
-                       const char (&aLiteral)[N])
-  {
-    EagerLogValue(aSubjectTypeName,
-                  aSubjectPointer,
-                  aCategory,
-                  aLabel,
-                  static_cast<const char*>(aLiteral));
-  }
-
-  template<typename Subject, size_t N>
-  static void LogValue(const Subject* aSubject,
-                       DDLogCategory aCategory,
-                       const char* aLabel,
-                       const char (&aLiteral)[N])
-  {
-    EagerLogValue(
-      aSubject, aCategory, aLabel, static_cast<const char*>(aLiteral));
-  }
-
-  // Same as LogValue above, but needed to be seen by DDLOG... macros.
-  template<size_t N>
+  // EagerLogValue that can explicitly take strings, as the templated function
+  // above confuses Variant when forwarding string literals.
   static void EagerLogValue(const char* aSubjectTypeName,
                             const void* aSubjectPointer,
                             DDLogCategory aCategory,
                             const char* aLabel,
-                            const char (&aLiteral)[N])
+                            const char* aValue)
   {
-    EagerLogValue(aSubjectTypeName,
-                  aSubjectPointer,
-                  aCategory,
-                  aLabel,
-                  static_cast<const char*>(aLiteral));
+    Log(aSubjectTypeName,
+        aSubjectPointer,
+        aCategory,
+        aLabel,
+        DDLogValue{ aValue });
   }
 
-  template<typename Subject, size_t N>
+  template<typename Subject>
   static void EagerLogValue(const Subject* aSubject,
                             DDLogCategory aCategory,
                             const char* aLabel,
-                            const char (&aLiteral)[N])
+                            const char* aValue)
   {
     EagerLogValue(
-      aSubject, aCategory, aLabel, static_cast<const char*>(aLiteral));
+      DDLoggedTypeTraits<Subject>::Name(), aSubject, aCategory, aLabel, aValue);
   }
 
   static void EagerLogPrintf(const char* aSubjectTypeName,
@@ -312,26 +286,34 @@ public:
   }
 
   template<typename Subject>
-  static void LogConstruction(const Subject* aSubject)
+  static void LogConstruction(NonDereferenceable<const Subject> aSubject)
   {
     using Traits = DDLoggedTypeTraits<Subject>;
     if (!Traits::HasBase::value) {
       Log(DDLoggedTypeTraits<Subject>::Name(),
-          aSubject,
+          reinterpret_cast<const void*>(aSubject.value()),
           DDLogCategory::_Construction,
           "",
           DDLogValue{ DDNoValue{} });
     } else {
       Log(DDLoggedTypeTraits<Subject>::Name(),
-          aSubject,
+          reinterpret_cast<const void*>(aSubject.value()),
           DDLogCategory::_DerivedConstruction,
           "",
           DDLogValue{ DDLogObject{
             DDLoggedTypeTraits<typename Traits::BaseType>::Name(),
-            static_cast<const typename Traits::BaseType*>(aSubject) } });
+            reinterpret_cast<const void*>(
+              NonDereferenceable<const typename Traits::BaseType>(aSubject)
+                .value()) } });
     }
   }
 
+  template<typename Subject>
+  static void LogConstruction(const Subject* aSubject)
+  {
+    LogConstruction(NonDereferenceable<const Subject>(aSubject));
+  }
+
   static void LogDestruction(const char* aSubjectTypeName,
                              const void* aSubjectPointer)
   {
@@ -343,15 +325,21 @@ public:
   }
 
   template<typename Subject>
-  static void LogDestruction(const Subject* aSubject)
+  static void LogDestruction(NonDereferenceable<const Subject> aSubject)
   {
     Log(DDLoggedTypeTraits<Subject>::Name(),
-        aSubject,
+        reinterpret_cast<const void*>(aSubject.value()),
         DDLogCategory::_Destruction,
         "",
         DDLogValue{ DDNoValue{} });
   }
 
+  template<typename Subject>
+  static void LogDestruction(const Subject* aSubject)
+  {
+    LogDestruction(NonDereferenceable<const Subject>(aSubject));
+  }
+
   template<typename P, typename C>
   static void LinkParentAndChild(const P* aParent,
                                  const char* aLinkName,
@@ -507,11 +495,11 @@ class DecoderDoctorLifeLogger
 public:
   DecoderDoctorLifeLogger()
   {
-    DecoderDoctorLogger::LogConstruction(static_cast<const T*>(this));
+    DecoderDoctorLogger::LogConstruction(NonDereferenceable<const T>(this));
   }
   ~DecoderDoctorLifeLogger()
   {
-    DecoderDoctorLogger::LogDestruction(static_cast<const T*>(this));
+    DecoderDoctorLogger::LogDestruction(NonDereferenceable<const T>(this));
   }
 };
 
