@@ -51,7 +51,7 @@ public:
   {
     Function func(aFunction);
     RefPtr<MP4DemuxerBinding> binding = this;
-    mDemuxer->Init()->Then(mTaskQueue, __func__, Move(func), DO_FAIL);
+    mDemuxer->Init()->Then(mTaskQueue, __func__, std::move(func), DO_FAIL);
     mTaskQueue->AwaitShutdownAndIdle();
   }
 
