@@ -180,7 +180,7 @@ OmxDataDecoder::Decode(MediaRawData* aSample)
   RefPtr<MediaRawData> sample = aSample;
   return InvokeAsync(mOmxTaskQueue, __func__, [self, this, sample]() {
     RefPtr<DecodePromise> p = mDecodePromise.Ensure(__func__);
-    mMediaRawDatas.AppendElement(Move(sample));
+    mMediaRawDatas.AppendElement(std::move(sample));
 
     // Start to fill/empty buffers.
     if (mOmxState == OMX_StateIdle ||
@@ -361,7 +361,7 @@ OmxDataDecoder::Output(BufferData* aData)
     aData->mStatus = BufferData::BufferStatus::FREE;
   }
 
-  mDecodedData.AppendElement(Move(data));
+  mDecodedData.AppendElement(std::move(data));
 }
 
 void
@@ -399,7 +399,9 @@ OmxDataDecoder::EmptyBufferDone(BufferData* aData)
         mDecodedData.Clear();
       });
 
-    mOmxTaskQueue->Dispatch(r.forget());
+    nsresult rv = mOmxTaskQueue->Dispatch(r.forget());
+    MOZ_DIAGNOSTIC_ASSERT(NS_SUCCEEDED(rv));
+    Unused << rv;
   }
 }
 
@@ -412,8 +414,8 @@ OmxDataDecoder::EmptyBufferFailure(OmxBufferFailureHolder aFailureHolder)
 void
 OmxDataDecoder::NotifyError(OMX_ERRORTYPE aOmxError, const char* aLine, const MediaResult& aError)
 {
-  LOG("NotifyError %d (%" PRIu32 ") at %s", static_cast<int>(aOmxError),
-      static_cast<uint32_t>(aError.Code()), aLine);
+  LOG("NotifyError %d (%s) at %s", static_cast<int>(aOmxError),
+      aError.ErrorName().get(), aLine);
   mDecodedData.Clear();
   mDecodePromise.RejectIfExists(aError, __func__);
   mDrainPromise.RejectIfExists(aError, __func__);
@@ -618,6 +620,9 @@ OmxDataDecoder::FillCodecConfigDataToOmx()
 
   // Some codecs like h264, its codec specific data is at the first packet, not in container.
   if (csc->Length()) {
+    // Buffer size should large enough for raw data.
+    MOZ_RELEASE_ASSERT(inbuf->mBuffer->nAllocLen >= csc->Length());
+
     memcpy(inbuf->mBuffer->pBuffer,
            csc->Elements(),
            csc->Length());
