@@ -7,7 +7,6 @@
 #include "WMFMediaDataDecoder.h"
 #include "VideoUtils.h"
 #include "WMFUtils.h"
-#include "mozilla/Telemetry.h"
 #include "nsTArray.h"
 
 #include "mozilla/Logging.h"
@@ -35,41 +34,6 @@ WMFMediaDataDecoder::Init()
   return InitPromise::CreateAndResolve(mMFTManager->GetType(), __func__);
 }
 
-// A single telemetry sample is reported for each MediaDataDecoder object
-// that has detected error or produced output successfully.
-static void
-SendTelemetry(unsigned long hr)
-{
-  // Collapse the error codes into a range of 0-0xff that can be viewed in
-  // telemetry histograms.  For most MF_E_* errors, unique samples are used,
-  // retaining the least significant 7 or 8 bits.  Other error codes are
-  // bucketed.
-  uint32_t sample;
-  if (SUCCEEDED(hr)) {
-    sample = 0;
-  } else if (hr < 0xc00d36b0) {
-    sample = 1; // low bucket
-  } else if (hr < 0xc00d3700) {
-    sample = hr & 0xffU; // MF_E_*
-  } else if (hr <= 0xc00d3705) {
-    sample = 0x80 + (hr & 0xfU); // more MF_E_*
-  } else if (hr < 0xc00d6d60) {
-    sample = 2; // mid bucket
-  } else if (hr <= 0xc00d6d78) {
-    sample = hr & 0xffU; // MF_E_TRANSFORM_*
-  } else {
-    sample = 3; // high bucket
-  }
-
-  nsCOMPtr<nsIRunnable> runnable = NS_NewRunnableFunction(
-    "SendTelemetry",
-    [sample] {
-      Telemetry::Accumulate(Telemetry::MEDIA_WMF_DECODE_ERROR, sample);
-    });
-
-  SystemGroup::Dispatch(TaskCategory::Other, runnable.forget());
-}
-
 RefPtr<ShutdownPromise>
 WMFMediaDataDecoder::Shutdown()
 {
@@ -90,9 +54,6 @@ WMFMediaDataDecoder::ProcessShutdown()
   if (mMFTManager) {
     mMFTManager->Shutdown();
     mMFTManager = nullptr;
-    if (!mRecordedError && mHasSuccessfulOutput) {
-      SendTelemetry(S_OK);
-    }
   }
   return ShutdownPromise::CreateAndResolve(true, __func__);
 }
@@ -112,7 +73,6 @@ RefPtr<MediaDataDecoder::DecodePromise>
 WMFMediaDataDecoder::ProcessError(HRESULT aError, const char* aReason)
 {
   if (!mRecordedError) {
-    SendTelemetry(aError);
     mRecordedError = true;
   }
 
