@@ -568,7 +568,7 @@ AudioContext::DecodeAudioData(const ArrayBuffer& aBuffer,
                           promise, successCallback, failureCallback));
   AsyncDecodeWebAudio(contentType.get(), data, length, *job);
   // Transfer the ownership to mDecodeJobs
-  mDecodeJobs.AppendElement(Move(job));
+  mDecodeJobs.AppendElement(std::move(job));
 
   return promise.forget();
 }
