@@ -473,7 +473,7 @@ WebAudioDecodeJob::AllocateBuffer()
 
   // Now create the AudioBuffer
   mOutput = AudioBuffer::Create(mContext->GetOwner(),
-                                mContext->SampleRate(), Move(mBuffer));
+                                mContext->SampleRate(), std::move(mBuffer));
   return mOutput != nullptr;
 }
 
@@ -510,17 +510,17 @@ AsyncDecodeWebAudio(const char* aContentType, uint8_t* aBuffer,
     // we might evaluate the task.forget() before calling Reader(). Enforce
     // a non-crashy order-of-operations.
     TaskQueue* taskQueue = task->Reader()->OwnerThread();
-    taskQueue->Dispatch(task.forget());
+    nsresult rv = taskQueue->Dispatch(task.forget());
+    MOZ_DIAGNOSTIC_ASSERT(NS_SUCCEEDED(rv));
+    Unused << rv;
   }
 }
 
-WebAudioDecodeJob::WebAudioDecodeJob(const nsACString& aContentType,
-                                     AudioContext* aContext,
+WebAudioDecodeJob::WebAudioDecodeJob(AudioContext* aContext,
                                      Promise* aPromise,
                                      DecodeSuccessCallback* aSuccessCallback,
                                      DecodeErrorCallback* aFailureCallback)
-  : mContentType(aContentType)
-  , mContext(aContext)
+  : mContext(aContext)
   , mPromise(aPromise)
   , mSuccessCallback(aSuccessCallback)
   , mFailureCallback(aFailureCallback)
@@ -609,7 +609,6 @@ size_t
 WebAudioDecodeJob::SizeOfExcludingThis(MallocSizeOf aMallocSizeOf) const
 {
   size_t amount = 0;
-  amount += mContentType.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
   if (mSuccessCallback) {
     amount += mSuccessCallback->SizeOfIncludingThis(aMallocSizeOf);
   }
