@@ -21,6 +21,7 @@
 
 #include "AudioSegment.h"
 #include "DOMMediaStream.h"
+#include "MediaEnginePrefs.h"
 #include "endpointer.h"
 
 #include "mozilla/dom/SpeechRecognitionEvent.h"
@@ -117,7 +118,7 @@ SpeechRecognition::SpeechRecognition(nsPIDOMWindowInner* aOwnerWindow)
   : DOMEventTargetHelper(aOwnerWindow)
   , mEndpointer(kSAMPLE_RATE)
   , mAudioSamplesPerChunk(mEndpointer.FrameSize())
-  , mSpeechDetectionTimer(do_CreateInstance(NS_TIMER_CONTRACTID))
+  , mSpeechDetectionTimer(NS_NewTimer())
   , mSpeechGrammarList(new SpeechGrammarList(GetParentObject()))
   , mInterimResults(false)
   , mMaxAlternatives(1)
@@ -754,7 +755,7 @@ SpeechRecognition::Start(const Optional<NonNull<DOMMediaStream>>& aStream,
   if (aStream.WasPassed()) {
     StartRecording(&aStream.Value());
   } else {
-    AutoNoJSAPI();
+    AutoNoJSAPI nojsapi;
     MediaManager* manager = MediaManager::Get();
     manager->GetUserMedia(GetOwner(),
                           constraints,
