@@ -17,11 +17,16 @@
 #include "mozilla/dom/AppNotificationServiceOptionsBinding.h"
 #include "mozilla/dom/BindingUtils.h"
 #include "mozilla/dom/ContentChild.h"
+#include "mozilla/dom/DOMPrefs.h"
 #include "mozilla/dom/NotificationEvent.h"
 #include "mozilla/dom/PermissionMessageUtils.h"
 #include "mozilla/dom/Promise.h"
 #include "mozilla/dom/PromiseWorkerProxy.h"
 #include "mozilla/dom/ServiceWorkerGlobalScopeBinding.h"
+#include "mozilla/dom/ServiceWorkerManager.h"
+#include "mozilla/dom/WorkerPrivate.h"
+#include "mozilla/dom/WorkerRunnable.h"
+#include "mozilla/dom/WorkerScope.h"
 
 #include "nsAlertsUtils.h"
 #include "nsComponentManagerUtils.h"
@@ -50,16 +55,10 @@
 #include "nsThreadUtils.h"
 #include "nsToolkitCompsCID.h"
 #include "nsXULAppAPI.h"
-#include "ServiceWorkerManager.h"
-#include "WorkerPrivate.h"
-#include "WorkerRunnable.h"
-#include "WorkerScope.h"
 
 namespace mozilla {
 namespace dom {
 
-using namespace workers;
-
 struct NotificationStrings
 {
   const nsString mID;
@@ -114,7 +113,7 @@ public:
       nsString(aServiceWorkerRegistrationScope),
     };
 
-    mStrings.AppendElement(Move(strings));
+    mStrings.AppendElement(std::move(strings));
     return NS_OK;
   }
 
@@ -514,7 +513,7 @@ public:
   NotificationTask(const char* aName, UniquePtr<NotificationRef> aRef,
                    NotificationAction aAction)
     : Runnable(aName)
-    , mNotificationRef(Move(aRef)), mAction(aAction)
+    , mNotificationRef(std::move(aRef)), mAction(aAction)
   {}
 
   NS_IMETHOD
@@ -707,7 +706,7 @@ public:
   NS_DECL_NSIOBSERVER
 
   explicit MainThreadNotificationObserver(UniquePtr<NotificationRef> aRef)
-    : mNotificationRef(Move(aRef))
+    : mNotificationRef(std::move(aRef))
   {
     AssertIsOnMainThread();
   }
@@ -743,39 +742,22 @@ NotificationTask::Run()
   return NS_OK;
 }
 
-bool
-Notification::RequireInteractionEnabled(JSContext* aCx, JSObject* aOjb)
-{
-  if (NS_IsMainThread()) {
-    return Preferences::GetBool("dom.webnotifications.requireinteraction.enabled", false);
-  }
-
-  WorkerPrivate* workerPrivate = GetWorkerPrivateFromContext(aCx);
-  if (!workerPrivate) {
-    return false;
-  }
-
-  return workerPrivate->DOMWorkerNotificationRIEnabled();
-}
-
 // static
 bool
 Notification::PrefEnabled(JSContext* aCx, JSObject* aObj)
 {
-  if (NS_IsMainThread()) {
-    return Preferences::GetBool("dom.webnotifications.enabled", false);
+  if (!NS_IsMainThread()) {
+    WorkerPrivate* workerPrivate = GetWorkerPrivateFromContext(aCx);
+    if (!workerPrivate) {
+      return false;
+    }
+
+    if (workerPrivate->IsServiceWorker()) {
+      return DOMPrefs::NotificationEnabledInServiceWorkers();
+    }
   }
 
-  WorkerPrivate* workerPrivate = GetWorkerPrivateFromContext(aCx);
-  if (!workerPrivate) {
-    return false;
-  }
-
-  if (workerPrivate->IsServiceWorker()) {
-    return workerPrivate->DOMServiceWorkerNotificationEnabled();
-  }
-
-  return workerPrivate->DOMWorkerNotificationEnabled();
+  return DOMPrefs::NotificationEnabled();
 }
 
 // static
@@ -1074,7 +1056,7 @@ public:
   NS_DECL_NSIOBSERVER
 
   explicit WorkerNotificationObserver(UniquePtr<NotificationRef> aRef)
-    : MainThreadNotificationObserver(Move(aRef))
+    : MainThreadNotificationObserver(std::move(aRef))
   {
     AssertIsOnMainThread();
     MOZ_ASSERT(mNotificationRef->GetNotification()->mWorkerPrivate);
@@ -1534,10 +1516,10 @@ Notification::ShowInternal()
       MOZ_ASSERT(!mWorkerPrivate->IsServiceWorker());
       // Keep a pointer so that the feature can tell the observer not to release
       // the notification.
-      mObserver = new WorkerNotificationObserver(Move(ownership));
+      mObserver = new WorkerNotificationObserver(std::move(ownership));
       observer = mObserver;
     } else {
-      observer = new MainThreadNotificationObserver(Move(ownership));
+      observer = new MainThreadNotificationObserver(std::move(ownership));
     }
   } else {
     isPersistent = true;
@@ -1574,7 +1556,7 @@ Notification::ShowInternal()
   bool inPrivateBrowsing = IsInPrivateBrowsing();
 
   bool requireInteraction = mRequireInteraction;
-  if (!Preferences::GetBool("dom.webnotifications.requireinteraction.enabled", false)) {
+  if (!DOMPrefs::NotificationRIEnabled()) {
     requireInteraction = false;
   }
 
@@ -1887,7 +1869,7 @@ public:
                           const nsTArray<NotificationStrings>&& aStrings)
     : NotificationWorkerRunnable(aWorkerPrivate)
     , mPromiseProxy(aPromiseProxy)
-    , mStrings(Move(aStrings))
+    , mStrings(std::move(aStrings))
   {
   }
 
@@ -1953,7 +1935,7 @@ public:
     RefPtr<WorkerGetResultRunnable> r =
       new WorkerGetResultRunnable(proxy->GetWorkerPrivate(),
                                   proxy,
-                                  Move(mStrings));
+                                  std::move(mStrings));
 
     r->Dispatch();
     return NS_OK;
@@ -2068,7 +2050,7 @@ Notification::Close()
   }
 
   nsCOMPtr<nsIRunnable> closeNotificationTask =
-    new NotificationTask("Notification::Close", Move(ref),
+    new NotificationTask("Notification::Close", std::move(ref),
                          NotificationTask::eClose);
   nsresult rv = DispatchToMainThread(closeNotificationTask.forget());
 
@@ -2274,7 +2256,7 @@ class CloseNotificationRunnable final
 };
 
 bool
-NotificationWorkerHolder::Notify(Status aStatus)
+NotificationWorkerHolder::Notify(WorkerStatus aStatus)
 {
   if (aStatus >= Canceling) {
     // CloseNotificationRunnable blocks the worker by pushing a sync event loop
@@ -2516,7 +2498,7 @@ Notification::CreateAndShow(JSContext* aCx,
 
   // Queue a task to show the notification.
   nsCOMPtr<nsIRunnable> showNotificationTask =
-    new NotificationTask("Notification::CreateAndShow", Move(ref),
+    new NotificationTask("Notification::CreateAndShow", std::move(ref),
                          NotificationTask::eShow);
 
   nsresult rv =
@@ -2584,17 +2566,17 @@ nsresult
 Notification::DispatchToMainThread(already_AddRefed<nsIRunnable>&& aRunnable)
 {
   if (mWorkerPrivate) {
-    return mWorkerPrivate->DispatchToMainThread(Move(aRunnable));
+    return mWorkerPrivate->DispatchToMainThread(std::move(aRunnable));
   }
   AssertIsOnMainThread();
   if (nsCOMPtr<nsIGlobalObject> global = GetOwnerGlobal()) {
     if (nsIEventTarget* target = global->EventTargetFor(TaskCategory::Other)) {
-      return target->Dispatch(Move(aRunnable), nsIEventTarget::DISPATCH_NORMAL);
+      return target->Dispatch(std::move(aRunnable), nsIEventTarget::DISPATCH_NORMAL);
     }
   }
   nsCOMPtr<nsIEventTarget> mainTarget = GetMainThreadEventTarget();
   MOZ_ASSERT(mainTarget);
-  return mainTarget->Dispatch(Move(aRunnable), nsIEventTarget::DISPATCH_NORMAL);
+  return mainTarget->Dispatch(std::move(aRunnable), nsIEventTarget::DISPATCH_NORMAL);
 }
 
 } // namespace dom
