@@ -89,11 +89,10 @@ PaymentResponse::GetDetails(JSContext* aCx, JS::MutableHandle<JSObject*> aRetVal
 
     MOZ_ASSERT(aCx);
     JS::RootedValue value(aCx);
-    JS::MutableHandleValue handleValue(&value);
-    if (NS_WARN_IF(!response.ToObjectInternal(aCx, handleValue))) {
+    if (NS_WARN_IF(!response.ToObjectInternal(aCx, &value))) {
       return;
     }
-    aRetVal.set(&handleValue.toObject());
+    aRetVal.set(&value.toObject());
   }
 }
 
