@@ -14,6 +14,9 @@
 #include "mozilla/dom/PushSubscription.h"
 #include "mozilla/dom/PushSubscriptionOptionsBinding.h"
 #include "mozilla/dom/PushUtil.h"
+#include "mozilla/dom/WorkerRunnable.h"
+#include "mozilla/dom/WorkerPrivate.h"
+#include "mozilla/dom/WorkerScope.h"
 
 #include "mozilla/dom/Promise.h"
 #include "mozilla/dom/PromiseWorkerProxy.h"
@@ -26,15 +29,9 @@
 #include "nsComponentManagerUtils.h"
 #include "nsContentUtils.h"
 
-#include "WorkerRunnable.h"
-#include "WorkerPrivate.h"
-#include "WorkerScope.h"
-
 namespace mozilla {
 namespace dom {
 
-using namespace workers;
-
 namespace {
 
 nsresult
@@ -155,13 +152,13 @@ public:
                                 nsTArray<uint8_t>&& aAuthSecret,
                                 nsTArray<uint8_t>&& aAppServerKey)
     : WorkerRunnable(aWorkerPrivate)
-    , mProxy(Move(aProxy))
+    , mProxy(std::move(aProxy))
     , mStatus(aStatus)
     , mEndpoint(aEndpoint)
     , mScope(aScope)
-    , mRawP256dhKey(Move(aRawP256dhKey))
-    , mAuthSecret(Move(aAuthSecret))
-    , mAppServerKey(Move(aAppServerKey))
+    , mRawP256dhKey(std::move(aRawP256dhKey))
+    , mAuthSecret(std::move(aAuthSecret))
+    , mAppServerKey(std::move(aAppServerKey))
   { }
 
   bool
@@ -174,8 +171,8 @@ public:
       } else {
         RefPtr<PushSubscription> sub =
             new PushSubscription(nullptr, mEndpoint, mScope,
-                                 Move(mRawP256dhKey), Move(mAuthSecret),
-                                 Move(mAppServerKey));
+                                 std::move(mRawP256dhKey), std::move(mAuthSecret),
+                                 std::move(mAppServerKey));
         promise->MaybeResolve(sub);
       }
     } else if (NS_ERROR_GET_MODULE(mStatus) == NS_ERROR_MODULE_DOM_PUSH ) {
@@ -238,9 +235,9 @@ public:
                                         aStatus,
                                         endpoint,
                                         mScope,
-                                        Move(rawP256dhKey),
-                                        Move(authSecret),
-                                        Move(appServerKey));
+                                        std::move(rawP256dhKey),
+                                        std::move(authSecret),
+                                        std::move(appServerKey));
     MOZ_ALWAYS_TRUE(r->Dispatch());
 
     return NS_OK;
@@ -276,7 +273,7 @@ public:
     , mProxy(aProxy)
     , mScope(aScope)
     , mAction(aAction)
-    , mAppServerKey(Move(aAppServerKey))
+    , mAppServerKey(std::move(aAppServerKey))
   {}
 
   NS_IMETHOD
@@ -592,7 +589,7 @@ PushManager::PerformSubscriptionActionFromWorker(SubscriptionAction aAction,
   }
 
   RefPtr<GetSubscriptionRunnable> r =
-    new GetSubscriptionRunnable(proxy, mScope, aAction, Move(appServerKey));
+    new GetSubscriptionRunnable(proxy, mScope, aAction, std::move(appServerKey));
   MOZ_ALWAYS_SUCCEEDS(NS_DispatchToMainThread(r));
 
   return p.forget();
