@@ -430,7 +430,8 @@ SRICheckDataVerifier::DataSummaryLength(uint32_t aDataLen, const uint8_t* aData,
 
   // decode the content of the buffer
   size_t offset = sizeof(mHashType);
-  size_t len = *reinterpret_cast<const decltype(mHashLength)*>(&aData[offset]);
+  decltype(mHashLength) len = 0;
+  memcpy(&len, &aData[offset], sizeof(mHashLength));
   offset += sizeof(mHashLength);
 
   SRIVERBOSE(("SRICheckDataVerifier::DataSummaryLength, header {%x, %x, %x, %x, %x, ...}",
@@ -467,18 +468,20 @@ SRICheckDataVerifier::ImportDataSummary(uint32_t aDataLen, const uint8_t* aData)
 
   // decode the content of the buffer
   size_t offset = 0;
-  if (*reinterpret_cast<const decltype(mHashType)*>(&aData[offset]) != mHashType) {
+  decltype(mHashType) hashType;
+  memcpy(&hashType, &aData[offset], sizeof(mHashType));
+  if (hashType != mHashType) {
     SRILOG(("SRICheckDataVerifier::ImportDataSummary, hash type[%d] does not match[%d]",
-            *reinterpret_cast<const decltype(mHashType)*>(&aData[offset]),
-             mHashType));
+            hashType, mHashType));
     return NS_ERROR_SRI_UNEXPECTED_HASH_TYPE;
   }
   offset += sizeof(mHashType);
 
-  if (*reinterpret_cast<const decltype(mHashLength)*>(&aData[offset]) != mHashLength) {
+  decltype(mHashLength) hashLength;
+  memcpy(&hashLength, &aData[offset], sizeof(mHashLength));
+  if (hashLength != mHashLength) {
     SRILOG(("SRICheckDataVerifier::ImportDataSummary, hash length[%d] does not match[%d]",
-            *reinterpret_cast<const decltype(mHashLength)*>(&aData[offset]),
-             mHashLength));
+            hashLength, mHashLength));
     return NS_ERROR_SRI_UNEXPECTED_HASH_TYPE;
   }
   offset += sizeof(mHashLength);
@@ -500,9 +503,9 @@ SRICheckDataVerifier::ExportDataSummary(uint32_t aDataLen, uint8_t* aData)
 
   // serialize the hash in the buffer
   size_t offset = 0;
-  *reinterpret_cast<decltype(mHashType)*>(&aData[offset]) = mHashType;
+  memcpy(&aData[offset], &mHashType, sizeof(mHashType));
   offset += sizeof(mHashType);
-  *reinterpret_cast<decltype(mHashLength)*>(&aData[offset]) = mHashLength;
+  memcpy(&aData[offset], &mHashLength, sizeof(mHashLength));
   offset += sizeof(mHashLength);
 
   SRIVERBOSE(("SRICheckDataVerifier::ExportDataSummary, header {%x, %x, %x, %x, %x, ...}",
@@ -522,9 +525,9 @@ SRICheckDataVerifier::ExportEmptyDataSummary(uint32_t aDataLen, uint8_t* aData)
 
   // serialize an unknown hash in the buffer, to be able to skip it later
   size_t offset = 0;
-  *reinterpret_cast<decltype(mHashType)*>(&aData[offset]) = 0;
+  memset(&aData[offset], 0, sizeof(mHashType));
   offset += sizeof(mHashType);
-  *reinterpret_cast<decltype(mHashLength)*>(&aData[offset]) = 0;
+  memset(&aData[offset], 0, sizeof(mHashLength));
   offset += sizeof(mHashLength);
 
   SRIVERBOSE(("SRICheckDataVerifier::ExportEmptyDataSummary, header {%x, %x, %x, %x, %x, ...}",
