@@ -613,7 +613,7 @@ InterpolateForServo(const ValueWrapper* aStartWrapper,
     }
     results.AppendElement(result);
   }
-  aResult.mU.mPtr = new ValueWrapper(aEndWrapper.mPropID, Move(results));
+  aResult.mU.mPtr = new ValueWrapper(aEndWrapper.mPropID, std::move(results));
 
   return NS_OK;
 }
@@ -805,7 +805,7 @@ nsSMILCSSValueType::ValueFromString(nsCSSPropertyID aPropID,
 
     if (!parsedValues.IsEmpty()) {
       sSingleton.Init(aValue);
-      aValue.mU.mPtr = new ValueWrapper(aPropID, Move(parsedValues));
+      aValue.mU.mPtr = new ValueWrapper(aPropID, std::move(parsedValues));
     }
     return;
   }
@@ -940,10 +940,10 @@ nsSMILCSSValueType::FinalizeValue(nsSMILValue& aValue,
       if (!zeroValue) {
         return;
       }
-      zeroValues.AppendElement(Move(zeroValue));
+      zeroValues.AppendElement(std::move(zeroValue));
     }
     aValue.mU.mPtr = new ValueWrapper(valueToMatchWrapper->mPropID,
-                                      Move(zeroValues));
+                                      std::move(zeroValues));
   } else {
 #ifdef MOZ_OLD_STYLE
     const StyleAnimationValue* zeroValue =
