@@ -49,13 +49,17 @@ public:
                               bool aCompileEventHandlers) override;
   virtual void UnbindFromTree(bool aDeep, bool aNullParent) override;
 
-  virtual nsresult UnsetAttr(int32_t aNamespaceID, nsIAtom* aAttribute,
-                             bool aNotify) override;
   // Element specializations
   virtual bool ParseAttribute(int32_t aNamespaceID,
                                 nsIAtom* aAttribute,
                                 const nsAString& aValue,
+                                nsIPrincipal* aMaybeScriptedPrincipal,
                                 nsAttrValue& aResult) override;
+  virtual nsresult AfterSetAttr(int32_t aNamespaceID, nsIAtom* aName,
+                                const nsAttrValue* aValue,
+                                const nsAttrValue* aOldValue,
+                                nsIPrincipal* aMaybeScriptedPrincipal,
+                                bool aNotify) override;
 
   // Public helper method: If our xlink:href attribute links to a <path>
   // element, this method returns a pointer to that element. Otherwise,
@@ -66,10 +70,18 @@ public:
   already_AddRefed<SVGAnimatedString> Href();
 
 protected:
-  class PathReference : public mozilla::dom::IDTracker {
+  /**
+   * Helper that provides a reference to the 'path' element with the ID that is
+   * referenced by the 'mpath' element's 'href' attribute, and that will
+   * invalidate the parent of the 'mpath' and update mutation observers to the
+   * new path element if the element that that ID identifies changes to a
+   * different element (or none).
+   */
+  class PathElementTracker final : public IDTracker {
   public:
-    explicit PathReference(SVGMPathElement* aMpathElement) :
-      mMpathElement(aMpathElement) {}
+    explicit PathElementTracker(SVGMPathElement* aMpathElement)
+      : mMpathElement(aMpathElement)
+    {}
   protected:
     // We need to be notified when target changes, in order to request a sample
     // (which will clear animation effects that used the old target-path
@@ -101,7 +113,7 @@ protected:
   enum { HREF, XLINK_HREF };
   nsSVGString        mStringAttributes[2];
   static StringInfo  sStringInfo[2];
-  PathReference      mHrefTarget;
+  PathElementTracker mPathTracker;
 };
 
 } // namespace dom
