@@ -41,7 +41,7 @@ public:
   explicit U2FTransaction(const nsCString& aClientData,
                           const U2FCallback&& aCallback)
     : mClientData(aClientData)
-    , mCallback(Move(aCallback))
+    , mCallback(std::move(aCallback))
     , mId(NextId())
   {
     MOZ_ASSERT(mId > 0);
