@@ -689,7 +689,7 @@ U2FSoftTokenManager::Register(const WebAuthnMakeCredentialInfo& aInfo)
   registrationBuf.AppendSECItem(signatureItem);
 
   WebAuthnMakeCredentialResult result((nsTArray<uint8_t>(registrationBuf)));
-  return U2FRegisterPromise::CreateAndResolve(Move(result), __func__);
+  return U2FRegisterPromise::CreateAndResolve(std::move(result), __func__);
 }
 
 bool
@@ -865,7 +865,7 @@ U2FSoftTokenManager::Sign(const WebAuthnGetAssertionInfo& aInfo)
   }
 
   WebAuthnGetAssertionResult result(chosenAppId, keyHandle, signature, extensions);
-  return U2FSignPromise::CreateAndResolve(Move(result), __func__);
+  return U2FSignPromise::CreateAndResolve(std::move(result), __func__);
 }
 
 void
