@@ -1,5 +1,5 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim:set ts=2 sw=2 sts=2 et cindent: */
+/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* vim: set ts=8 sts=2 et sw=2 tw=80: */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -8,6 +8,7 @@
 #define mozilla_dom_WebAuthnTransactionChild_h
 
 #include "mozilla/dom/PWebAuthnTransactionChild.h"
+#include "mozilla/dom/WebAuthnManagerBase.h"
 
 /*
  * Child process IPC implementation for WebAuthn API. Receives results of
@@ -23,14 +24,28 @@ class WebAuthnTransactionChild final : public PWebAuthnTransactionChild
 {
 public:
   NS_INLINE_DECL_REFCOUNTING(WebAuthnTransactionChild);
-  WebAuthnTransactionChild();
-  mozilla::ipc::IPCResult RecvConfirmRegister(nsTArray<uint8_t>&& aRegBuffer) override;
-  mozilla::ipc::IPCResult RecvConfirmSign(nsTArray<uint8_t>&& aCredentialId,
-                                          nsTArray<uint8_t>&& aBuffer) override;
-  mozilla::ipc::IPCResult RecvCancel(const nsresult& aError) override;
+  explicit WebAuthnTransactionChild(WebAuthnManagerBase* aManager);
+
+  mozilla::ipc::IPCResult
+  RecvConfirmRegister(const uint64_t& aTransactionId,
+                      const WebAuthnMakeCredentialResult& aResult) override;
+
+  mozilla::ipc::IPCResult
+  RecvConfirmSign(const uint64_t& aTransactionId,
+                  const WebAuthnGetAssertionResult& aResult) override;
+
+  mozilla::ipc::IPCResult
+  RecvAbort(const uint64_t& aTransactionId, const nsresult& aError) override;
+
   void ActorDestroy(ActorDestroyReason why) override;
+
+  void Disconnect();
+
 private:
   ~WebAuthnTransactionChild() = default;
+
+  // Nulled by ~WebAuthnManager() when disconnecting.
+  WebAuthnManagerBase* mManager;
 };
 
 }
