@@ -68,7 +68,6 @@
 #define CLOSE_EVENT_STRING NS_LITERAL_STRING("close")
 
 using namespace mozilla::net;
-using namespace mozilla::dom::workers;
 
 namespace mozilla {
 namespace dom {
@@ -100,6 +99,7 @@ public:
   , mScriptLine(0)
   , mScriptColumn(0)
   , mInnerWindowID(0)
+  , mPrivateBrowsing(false)
   , mWorkerPrivate(nullptr)
 #ifdef DEBUG
   , mHasWorkerHolderRegistered(false)
@@ -212,6 +212,7 @@ public:
   uint32_t mScriptLine;
   uint32_t mScriptColumn;
   uint64_t mInnerWindowID;
+  bool mPrivateBrowsing;
 
   WorkerPrivate* mWorkerPrivate;
   nsAutoPtr<WorkerHolder> mWorkerHolder;
@@ -391,7 +392,8 @@ WebSocketImpl::PrintErrorOnConsole(const char *aBundleURI,
     rv = errorObject->Init(message,
                            NS_ConvertUTF8toUTF16(mScriptFile),
                            EmptyString(), mScriptLine, mScriptColumn,
-                           nsIScriptError::errorFlag, "Web Socket");
+                           nsIScriptError::errorFlag, "Web Socket",
+                           mPrivateBrowsing);
   }
 
   NS_ENSURE_SUCCESS_VOID(rv);
@@ -1571,6 +1573,8 @@ WebSocketImpl::Init(JSContext* aCx,
     mInnerWindowID = nsJSUtils::GetCurrentlyRunningCodeInnerWindowID(aCx);
   }
 
+  mPrivateBrowsing = !!aPrincipal->OriginAttributesRef().mPrivateBrowsingId;
+
   // parses the url
   rv = ParseURL(PromiseFlatString(aURL));
   NS_ENSURE_SUCCESS(rv, rv);
@@ -1643,7 +1647,8 @@ WebSocketImpl::Init(JSContext* aCx,
                         0, // aLineNumber
                         0, // aColumnNumber
                         nsIScriptError::warningFlag, "CSP",
-                        mInnerWindowID);
+                        mInnerWindowID,
+                        mPrivateBrowsing);
   }
 
   // Don't allow https:// to open ws://
@@ -2260,9 +2265,9 @@ public:
   {
   }
 
-  bool Notify(Status aStatus) override
+  bool Notify(WorkerStatus aStatus) override
   {
-    MOZ_ASSERT(aStatus > workers::Running);
+    MOZ_ASSERT(aStatus > Running);
 
     if (aStatus >= Canceling) {
       {
@@ -2821,7 +2826,7 @@ public:
                            already_AddRefed<nsIRunnable> aEvent)
     : WorkerRunnable(aWorkerPrivate, WorkerThreadUnchangedBusyCount)
     , mWebSocketImpl(aImpl)
-    , mEvent(Move(aEvent))
+    , mEvent(std::move(aEvent))
   {
   }
 
