@@ -7,9 +7,12 @@
 #ifndef mozilla_dom_workers_WorkerHolder_h
 #define mozilla_dom_workers_WorkerHolder_h
 
-#include "mozilla/dom/workers/Workers.h"
+#include "mozilla/dom/WorkerCommon.h"
 
-BEGIN_WORKERS_NAMESPACE
+namespace mozilla {
+namespace dom {
+
+class WorkerPrivate;
 
 /**
  * Use this chart to help figure out behavior during each of the closing
@@ -35,7 +38,7 @@ BEGIN_WORKERS_NAMESPACE
    it'll override our member name */
 #undef Status
 #endif
-enum Status
+enum WorkerStatus
 {
   // Not yet scheduled.
   Pending = 0,
@@ -81,10 +84,10 @@ public:
                         Behavior aBehavior = PreventIdleShutdownStart);
   virtual ~WorkerHolder();
 
-  bool HoldWorker(WorkerPrivate* aWorkerPrivate, Status aFailStatus);
+  bool HoldWorker(WorkerPrivate* aWorkerPrivate, WorkerStatus aFailStatus);
   void ReleaseWorker();
 
-  virtual bool Notify(Status aStatus) = 0;
+  virtual bool Notify(WorkerStatus aStatus) = 0;
 
   Behavior GetBehavior() const;
 
@@ -109,6 +112,7 @@ private:
   const char* mName;
 };
 
-END_WORKERS_NAMESPACE
+} // dom namespace
+} // mozilla namespace
 
 #endif /* mozilla_dom_workers_WorkerHolder_h */
