@@ -652,34 +652,34 @@ TEST(ServiceWorkerRegistrar, TestVersion7Migration)
 {
   nsAutoCString buffer("7" "\n");
 
-  buffer.Append("^appId=123&inBrowser=1\n");
+  buffer.AppendLiteral("^appId=123&inBrowser=1\n");
   buffer.AppendLiteral("https://scope_0.org\ncurrentWorkerURL 0\n");
-  buffer.Append(SERVICEWORKERREGISTRAR_TRUE "\n");
-  buffer.Append("cacheName 0\n");
+  buffer.AppendLiteral(SERVICEWORKERREGISTRAR_TRUE "\n");
+  buffer.AppendLiteral("cacheName 0\n");
   buffer.AppendInt(nsIRequest::LOAD_NORMAL, 16);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendInt(0);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendInt(0);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendInt(0);
-  buffer.Append("\n");
-  buffer.Append(SERVICEWORKERREGISTRAR_TERMINATOR "\n");
+  buffer.AppendLiteral("\n");
+  buffer.AppendLiteral(SERVICEWORKERREGISTRAR_TERMINATOR "\n");
 
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendLiteral("https://scope_1.org\ncurrentWorkerURL 1\n");
-  buffer.Append(SERVICEWORKERREGISTRAR_FALSE "\n");
-  buffer.Append("cacheName 1\n");
+  buffer.AppendLiteral(SERVICEWORKERREGISTRAR_FALSE "\n");
+  buffer.AppendLiteral("cacheName 1\n");
   buffer.AppendInt(nsIRequest::VALIDATE_ALWAYS, 16);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   PRTime ts = PR_Now();
   buffer.AppendInt(ts);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendInt(ts);
-  buffer.Append("\n");
+  buffer.AppendLiteral("\n");
   buffer.AppendInt(ts);
-  buffer.Append("\n");
-  buffer.Append(SERVICEWORKERREGISTRAR_TERMINATOR "\n");
+  buffer.AppendLiteral("\n");
+  buffer.AppendLiteral(SERVICEWORKERREGISTRAR_TERMINATOR "\n");
 
   ASSERT_TRUE(CreateFile(buffer)) << "CreateFile should not fail";
 
