@@ -10,7 +10,7 @@ var modifyObserver = {
         var ir = subject.QueryInterface(Ci.nsIChannel).notificationCallbacks;
 
         // The notificationCallbacks should be an nsIInterfaceRequestor.
-        testOk = ir.toString().indexOf(Ci.nsIInterfaceRequestor) != -1;
+        testOk = ir.toString().includes(Ci.nsIInterfaceRequestor);
       } catch (e) {
       }
       sendAsyncMessage('modify-request-completed', testOk);
