@@ -631,8 +631,7 @@ txSyncCompileObserver::loadURI(const nsAString& aUri,
     // make sense.
     nsCOMPtr<nsINode> source;
     if (mProcessor) {
-      source =
-        do_QueryInterface(mProcessor->GetSourceContentModel());
+      source = mProcessor->GetSourceContentModel();
     }
     nsAutoSyncOperation sync(source ? source->OwnerDoc() : nullptr);
     nsCOMPtr<nsIDOMDocument> document;
