@@ -1491,8 +1491,7 @@ nsXULContentBuilder::GetResultForContent(Element& aElement)
 //
 
 void
-nsXULContentBuilder::AttributeChanged(nsIDocument* aDocument,
-                                      Element*     aElement,
+nsXULContentBuilder::AttributeChanged(Element*     aElement,
                                       int32_t      aNameSpaceID,
                                       nsIAtom*     aAttribute,
                                       int32_t      aModType,
@@ -1521,7 +1520,7 @@ nsXULContentBuilder::AttributeChanged(nsIDocument* aDocument,
         mSortState.initialized = false;
 
     // Pass along to the generic template builder.
-    nsXULTemplateBuilder::AttributeChanged(aDocument, aElement, aNameSpaceID,
+    nsXULTemplateBuilder::AttributeChanged(aElement, aNameSpaceID,
                                            aAttribute, aModType, aOldValue);
 }
 
