@@ -1181,8 +1181,7 @@ nsXULTemplateBuilder::Observe(nsISupports* aSubject,
 //
 
 void
-nsXULTemplateBuilder::AttributeChanged(nsIDocument* aDocument,
-                                       Element*     aElement,
+nsXULTemplateBuilder::AttributeChanged(Element*     aElement,
                                        int32_t      aNameSpaceID,
                                        nsIAtom*     aAttribute,
                                        int32_t      aModType,
@@ -1210,9 +1209,7 @@ nsXULTemplateBuilder::AttributeChanged(nsIDocument* aDocument,
 }
 
 void
-nsXULTemplateBuilder::ContentRemoved(nsIDocument* aDocument,
-                                     nsIContent* aContainer,
-                                     nsIContent* aChild,
+nsXULTemplateBuilder::ContentRemoved(nsIContent* aChild,
                                      nsIContent* aPreviousSibling)
 {
     if (mRoot && nsContentUtils::ContentIsDescendantOf(mRoot, aChild)) {
@@ -1227,10 +1224,11 @@ nsXULTemplateBuilder::ContentRemoved(nsIDocument* aDocument,
                             this,
                             &nsXULTemplateBuilder::UninitFalse));
 
-        MOZ_ASSERT(aDocument == mObservedDocument);
+        MOZ_ASSERT(aChild->OwnerDoc() == mObservedDocument);
         StopObserving();
 
-        nsCOMPtr<nsIXULDocument> xuldoc = do_QueryInterface(aDocument);
+        nsCOMPtr<nsIXULDocument> xuldoc =
+            do_QueryInterface(aChild->OwnerDoc());
         if (xuldoc)
             xuldoc->SetTemplateBuilderFor(mRoot, nullptr);
 
