@@ -275,7 +275,7 @@ public:
 
     void SetTransport(UniquePtr<Transport> aTrans)
     {
-        mTrans = Move(aTrans);
+        mTrans = std::move(aTrans);
     }
 
     Transport* GetTransport() const { return mTrans.get(); }
@@ -673,7 +673,7 @@ public:
             return false;
         }
         mValid = false;
-        aActor->SetTransport(Move(t));
+        aActor->SetTransport(std::move(t));
         return true;
     }
 
