@@ -3,7 +3,10 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import os, sys
+from __future__ import print_function
+
+import os
+import sys
 
 from ipdl.ast import CxxInclude, Decl, Loc, QualifiedId, StructDecl
 from ipdl.ast import TypeSpec, UnionDecl, UsingStmt, Visitor
@@ -20,8 +23,8 @@ class TypeVisitor:
         self.visited = set()
 
     def defaultVisit(self, node, *args):
-        raise Exception, "INTERNAL ERROR: no visitor for node type `%s'"% (
-            node.__class__.__name__)
+        raise Exception("INTERNAL ERROR: no visitor for node type `%s'" %
+                        (node.__class__.__name__))
 
     def visitVoidType(self, v, *args):
         pass
@@ -67,6 +70,9 @@ class TypeVisitor:
     def visitShmemType(self, s, *args):
         pass
 
+    def visitByteBufType(self, s, *args):
+        pass
+
     def visitShmemChmodType(self, c, *args):
         c.shmem.accept(self)
 
@@ -76,12 +82,15 @@ class TypeVisitor:
     def visitEndpointType(self, s, *args):
         pass
 
+
 class Type:
     def __cmp__(self, o):
         return cmp(self.fullname(), o.fullname())
+
     def __eq__(self, o):
         return (self.__class__ == o.__class__
                 and self.fullname() == o.fullname())
+
     def __hash__(self):
         return hash(self.fullname())
 
@@ -89,64 +98,82 @@ class Type:
     def isCxx(self):
         return False
     # Is this an IPDL type?
+
     def isIPDL(self):
         return False
     # Is this type neither compound nor an array?
+
     def isAtom(self):
         return False
+
     def typename(self):
         return self.__class__.__name__
 
-    def name(self): raise Exception, 'NYI'
-    def fullname(self): raise Exception, 'NYI'
+    def name(self):
+        raise NotImplementedError()
+
+    def fullname(self):
+        raise NotImplementedError()
 
     def accept(self, visitor, *args):
-        visit = getattr(visitor, 'visit'+ self.__class__.__name__, None)
+        visit = getattr(visitor, 'visit' + self.__class__.__name__, None)
         if visit is None:
             return getattr(visitor, 'defaultVisit')(self, *args)
         return visit(self, *args)
 
+
 class VoidType(Type):
     def isCxx(self):
         return True
+
     def isIPDL(self):
         return False
+
     def isAtom(self):
         return True
 
     def name(self): return 'void'
     def fullname(self): return 'void'
 
+
 VOID = VoidType()
 
-##--------------------
+# --------------------
+
+
 class ImportedCxxType(Type):
     def __init__(self, qname):
         assert isinstance(qname, QualifiedId)
         self.loc = qname.loc
         self.qname = qname
+
     def isCxx(self):
         return True
+
     def isAtom(self):
         return True
 
     def name(self):
         return self.qname.baseid
+
     def fullname(self):
         return str(self.qname)
 
-##--------------------
+# --------------------
+
+
 class IPDLType(Type):
-    def isIPDL(self):  return True
+    def isIPDL(self): return True
     def isMessage(self): return False
     def isProtocol(self): return False
     def isActor(self): return False
     def isStruct(self): return False
     def isUnion(self): return False
     def isArray(self): return False
-    def isAtom(self):  return True
+    def isAtom(self): return True
     def isCompound(self): return False
     def isShmem(self): return False
+    def isByteBuf(self): return False
     def isFD(self): return False
     def isEndpoint(self): return False
 
@@ -154,18 +181,28 @@ class IPDLType(Type):
     def isSync(self): return self.sendSemantics == SYNC
     def isInterrupt(self): return self.sendSemantics is INTR
 
-    def hasReply(self):  return (self.isSync() or self.isInterrupt())
+    def hasReply(self): return (self.isSync() or self.isInterrupt())
 
     @classmethod
     def convertsTo(cls, lesser, greater):
-        if (lesser.nestedRange[0] < greater.nestedRange[0] or
-            lesser.nestedRange[1] > greater.nestedRange[1]):
+        def _unwrap(nr):
+            if isinstance(nr, dict):
+                return _unwrap(nr['nested'])
+            elif isinstance(nr, int):
+                return nr
+            else:
+                raise ValueError('Got unexpected nestedRange value: %s' % nr)
+
+        lnr0, gnr0, lnr1, gnr1 = (
+            _unwrap(lesser.nestedRange[0]), _unwrap(greater.nestedRange[0]),
+            _unwrap(lesser.nestedRange[1]), _unwrap(greater.nestedRange[1]))
+        if (lnr0 < gnr0 or lnr1 > gnr1):
             return False
 
         # Protocols that use intr semantics are not allowed to use
         # message nesting.
-        if (greater.isInterrupt() and
-            lesser.nestedRange != (NOT_NESTED, NOT_NESTED)):
+        if (greater.isInterrupt()
+            and lesser.nestedRange != (NOT_NESTED, NOT_NESTED)):
             return False
 
         if lesser.isAsync():
@@ -180,6 +217,7 @@ class IPDLType(Type):
     def needsMoreJuiceThan(self, o):
         return not IPDLType.convertsTo(self, o)
 
+
 class MessageType(IPDLType):
     def __init__(self, nested, prio, sendSemantics, direction,
                  ctor=False, dtor=False, cdtype=None, compress=False,
@@ -192,18 +230,19 @@ class MessageType(IPDLType):
         self.nestedRange = (nested, nested)
         self.sendSemantics = sendSemantics
         self.direction = direction
-        self.params = [ ]
-        self.returns = [ ]
+        self.params = []
+        self.returns = []
         self.ctor = ctor
         self.dtor = dtor
         self.cdtype = cdtype
         self.compress = compress
         self.verify = verify
+
     def isMessage(self): return True
 
     def isCtor(self): return self.ctor
     def isDtor(self): return self.dtor
-    def constructedType(self):  return self.cdtype
+    def constructedType(self): return self.cdtype
 
     def isIn(self): return self.direction is IN
     def isOut(self): return self.direction is OUT
@@ -214,19 +253,22 @@ class MessageType(IPDLType):
     def hasImplicitActorParam(self):
         return self.isCtor() or self.isDtor()
 
+
 class ProtocolType(IPDLType):
     def __init__(self, qname, nested, sendSemantics):
         self.qname = qname
         self.nestedRange = (NOT_NESTED, nested)
         self.sendSemantics = sendSemantics
         self.managers = []           # ProtocolType
-        self.manages = [ ]
+        self.manages = []
         self.hasDelete = False
         self.hasReentrantDelete = False
+
     def isProtocol(self): return True
 
     def name(self):
         return self.qname.baseid
+
     def fullname(self):
         return str(self.qname)
 
@@ -258,39 +300,50 @@ class ProtocolType(IPDLType):
             if pt is managed:
                 return True
         return False
+
     def isManagedBy(self, pt):
         return pt in self.managers
 
     def isManager(self):
         return len(self.manages) > 0
+
     def isManaged(self):
         return 0 < len(self.managers)
+
     def isToplevel(self):
         return not self.isManaged()
 
     def manager(self):
         assert 1 == len(self.managers)
-        for mgr in self.managers: return mgr
+        for mgr in self.managers:
+            return mgr
+
 
 class ActorType(IPDLType):
-    def __init__(self, protocol, nullable=0):
+    def __init__(self, protocol, nullable=False):
         self.protocol = protocol
         self.nullable = nullable
+
     def isActor(self): return True
 
     def name(self):
         return self.protocol.name()
+
     def fullname(self):
         return self.protocol.fullname()
 
+
 class _CompoundType(IPDLType):
     def __init__(self):
         self.defined = False            # bool
         self.mutualRec = set()          # set(_CompoundType | ArrayType)
+
     def isAtom(self):
         return False
+
     def isCompound(self):
         return True
+
     def itercomponents(self):
         raise Exception('"pure virtual" method')
 
@@ -307,7 +360,8 @@ looks for such a cycle and returns True if found.'''
             return True
         elif t.isArray():
             isrec = self.mutuallyRecursiveWith(t.basetype, exploring)
-            if isrec:  self.mutualRec.add(t)
+            if isrec:
+                self.mutualRec.add(t)
             return isrec
         elif t in exploring:
             return False
@@ -321,73 +375,106 @@ looks for such a cycle and returns True if found.'''
 
         return False
 
+
 class StructType(_CompoundType):
     def __init__(self, qname, fields):
         _CompoundType.__init__(self)
         self.qname = qname
         self.fields = fields            # [ Type ]
 
-    def isStruct(self):   return True
+    def isStruct(self): return True
+
     def itercomponents(self):
         for f in self.fields:
             yield f
 
     def name(self): return self.qname.baseid
+
     def fullname(self): return str(self.qname)
 
+
 class UnionType(_CompoundType):
     def __init__(self, qname, components):
         _CompoundType.__init__(self)
         self.qname = qname
         self.components = components    # [ Type ]
 
-    def isUnion(self):    return True
+    def isUnion(self): return True
+
     def itercomponents(self):
         for c in self.components:
             yield c
 
     def name(self): return self.qname.baseid
+
     def fullname(self): return str(self.qname)
 
+
 class ArrayType(IPDLType):
     def __init__(self, basetype):
         self.basetype = basetype
-    def isAtom(self):  return False
+
+    def isAtom(self): return False
+
     def isArray(self): return True
 
-    def name(self): return self.basetype.name() +'[]'
-    def fullname(self): return self.basetype.fullname() +'[]'
+    def name(self): return self.basetype.name() + '[]'
+
+    def fullname(self): return self.basetype.fullname() + '[]'
+
 
 class ShmemType(IPDLType):
     def __init__(self, qname):
         self.qname = qname
+
     def isShmem(self): return True
 
     def name(self):
         return self.qname.baseid
+
     def fullname(self):
         return str(self.qname)
 
+
+class ByteBufType(IPDLType):
+    def __init__(self, qname):
+        self.qname = qname
+
+    def isByteBuf(self): return True
+
+    def name(self):
+        return self.qname.baseid
+
+    def fullname(self):
+        return str(self.qname)
+
+
 class FDType(IPDLType):
     def __init__(self, qname):
         self.qname = qname
+
     def isFD(self): return True
 
     def name(self):
         return self.qname.baseid
+
     def fullname(self):
         return str(self.qname)
 
+
 class EndpointType(IPDLType):
     def __init__(self, qname):
         self.qname = qname
+
     def isEndpoint(self): return True
 
     def name(self):
         return self.qname.baseid
+
     def fullname(self):
         return str(self.qname)
 
+
 def iteractortypes(t, visited=None):
     """Iterate over any actor(s) buried in |type|."""
     if visited is None:
@@ -407,19 +494,25 @@ def iteractortypes(t, visited=None):
             for actor in iteractortypes(c, visited):
                 yield actor
 
+
 def hasshmem(type):
     """Return true iff |type| is shmem or has it buried within."""
-    class found: pass
+    class found(BaseException):
+        pass
+
     class findShmem(TypeVisitor):
-        def visitShmemType(self, s):  raise found()
+        def visitShmemType(self, s): raise found()
     try:
         type.accept(findShmem())
     except found:
         return True
     return False
 
-##--------------------
+
+# --------------------
 _builtinloc = Loc('<builtin>', 0)
+
+
 def makeBuiltinUsing(tname):
     quals = tname.split('::')
     base = quals.pop()
@@ -428,27 +521,33 @@ def makeBuiltinUsing(tname):
                      TypeSpec(_builtinloc,
                               QualifiedId(_builtinloc, base, quals)))
 
-builtinUsing = [ makeBuiltinUsing(t) for t in builtin.Types ]
-builtinHeaderIncludes = [ CxxInclude(_builtinloc, f) for f in builtin.HeaderIncludes ]
+
+builtinUsing = [makeBuiltinUsing(t) for t in builtin.Types]
+builtinHeaderIncludes = [CxxInclude(_builtinloc, f) for f in builtin.HeaderIncludes]
+
 
 def errormsg(loc, fmt, *args):
     while not isinstance(loc, Loc):
-        if loc is None:  loc = Loc.NONE
-        else:            loc = loc.loc
-    return '%s: error: %s'% (str(loc), fmt % args)
+        if loc is None:
+            loc = Loc.NONE
+        else:
+            loc = loc.loc
+    return '%s: error: %s' % (str(loc), fmt % args)
+
+# --------------------
+
 
-##--------------------
 class SymbolTable:
     def __init__(self, errors):
         self.errors = errors
-        self.scopes = [ { } ]   # stack({})
+        self.scopes = [{}]   # stack({})
         self.currentScope = self.scopes[0]
 
     def enterScope(self):
         assert isinstance(self.scopes[0], dict)
         assert isinstance(self.currentScope, dict)
 
-        self.scopes.append({ })
+        self.scopes.append({})
         self.currentScope = self.scopes[-1]
 
     def exitScope(self):
@@ -466,7 +565,8 @@ class SymbolTable:
         # |sym|
         for scope in self.scopes:
             decl = scope.get(sym, None)
-            if decl is not None:  return decl
+            if decl is not None:
+                return decl
         return None
 
     def declare(self, decl):
@@ -478,16 +578,19 @@ class SymbolTable:
             olddecl = self.lookup(name)
             if olddecl is not None:
                 self.errors.append(errormsg(
-                        decl.loc,
-                        "redeclaration of symbol `%s', first declared at %s",
-                        name, olddecl.loc))
+                    decl.loc,
+                    "redeclaration of symbol `%s', first declared at %s",
+                    name, olddecl.loc))
                 return
             self.currentScope[name] = decl
             decl.scope = self.currentScope
 
-        if decl.progname:  tryadd(decl.progname)
-        if decl.shortname: tryadd(decl.shortname)
-        if decl.fullname:  tryadd(decl.fullname)
+        if decl.progname:
+            tryadd(decl.progname)
+        if decl.shortname:
+            tryadd(decl.shortname)
+        if decl.fullname:
+            tryadd(decl.fullname)
 
 
 class TypeCheck:
@@ -500,7 +603,7 @@ With this information, it type checks the AST.'''
     def __init__(self):
         # NB: no IPDL compile will EVER print a warning.  A program has
         # one of two attributes: it is either well typed, or not well typed.
-        self.errors = [ ]       # [ string ]
+        self.errors = []       # [ string ]
 
     def check(self, tu, errout=sys.stderr):
         def runpass(tcheckpass):
@@ -523,7 +626,7 @@ With this information, it type checks the AST.'''
 
     def reportErrors(self, errout):
         for error in self.errors:
-            print >>errout, error
+            print(error, file=errout)
 
 
 class TcheckVisitor(Visitor):
@@ -533,6 +636,7 @@ class TcheckVisitor(Visitor):
     def error(self, loc, fmt, *args):
         self.errors.append(errormsg(loc, fmt, *args))
 
+
 class GatherDecls(TcheckVisitor):
     def __init__(self, builtinUsing, errors):
         TcheckVisitor.__init__(self, errors)
@@ -566,13 +670,13 @@ class GatherDecls(TcheckVisitor):
         # for everyone's sanity, enforce that the filename and tu name
         # match
         basefilename = os.path.basename(tu.filename)
-        expectedfilename = '%s.ipdl'% (tu.name)
+        expectedfilename = '%s.ipdl' % (tu.name)
         if not tu.protocol:
             # header
             expectedfilename += 'h'
         if basefilename != expectedfilename:
             self.error(tu.loc,
-                       "expected file for translation unit `%s' to be named `%s'; instead it's named `%s'",
+                       "expected file for translation unit `%s' to be named `%s'; instead it's named `%s'",  # NOQA: E501
                        tu.name, expectedfilename, basefilename)
 
         if tu.protocol:
@@ -595,11 +699,13 @@ class GatherDecls(TcheckVisitor):
 
             p.parentEndpointDecl = self.declare(
                 loc=p.loc,
-                type=EndpointType(QualifiedId(p.loc, 'Endpoint<' + fullname + 'Parent>', ['mozilla', 'ipc'])),
+                type=EndpointType(QualifiedId(p.loc, 'Endpoint<'
+                                              + fullname + 'Parent>', ['mozilla', 'ipc'])),
                 shortname='Endpoint<' + p.name + 'Parent>')
             p.childEndpointDecl = self.declare(
                 loc=p.loc,
-                type=EndpointType(QualifiedId(p.loc, 'Endpoint<' + fullname + 'Child>', ['mozilla', 'ipc'])),
+                type=EndpointType(QualifiedId(p.loc, 'Endpoint<'
+                                              + fullname + 'Child>', ['mozilla', 'ipc'])),
                 shortname='Endpoint<' + p.name + 'Child>')
 
             # XXX ugh, this sucks.  but we need this information to compute
@@ -643,10 +749,11 @@ class GatherDecls(TcheckVisitor):
             fullname = str(qname)
 
         if isinstance(su, StructDecl):
-            sutype = StructType(qname, [ ])
+            sutype = StructType(qname, [])
         elif isinstance(su, UnionDecl):
-            sutype = UnionType(qname, [ ])
-        else: assert 0 and 'unknown type'
+            sutype = UnionType(qname, [])
+        else:
+            assert 0 and 'unknown type'
 
         # XXX more suckage.  this time for pickling structs/unions
         # declared in headers.
@@ -658,7 +765,6 @@ class GatherDecls(TcheckVisitor):
             shortname=su.name,
             fullname=fullname)
 
-
     def visitInclude(self, inc):
         if inc.tu is None:
             self.error(
@@ -725,6 +831,8 @@ class GatherDecls(TcheckVisitor):
             fullname = None
         if fullname == 'mozilla::ipc::Shmem':
             ipdltype = ShmemType(using.type.spec)
+        elif fullname == 'mozilla::ipc::ByteBuf':
+            ipdltype = ByteBufType(using.type.spec)
         elif fullname == 'mozilla::ipc::FileDescriptor':
             ipdltype = FDType(using.type.spec)
         else:
@@ -775,16 +883,17 @@ class GatherDecls(TcheckVisitor):
                 "destructor declaration `%s(...)' required for managed protocol `%s'",
                 _DELETE_MSG, p.name)
 
-        p.decl.type.hasReentrantDelete = p.decl.type.hasDelete and self.symtab.lookup(_DELETE_MSG).type.isInterrupt()
+        p.decl.type.hasReentrantDelete = p.decl.type.hasDelete and self.symtab.lookup(
+            _DELETE_MSG).type.isInterrupt()
 
         for managed in p.managesStmts:
             mgdname = managed.name
-            ctordecl = self.symtab.lookup(mgdname +'Constructor')
+            ctordecl = self.symtab.lookup(mgdname + 'Constructor')
 
             if not (ctordecl and ctordecl.type.isCtor()):
                 self.error(
                     managed.loc,
-                    "constructor declaration required for managed protocol `%s' (managed by protocol `%s')",
+                    "constructor declaration required for managed protocol `%s' (managed by protocol `%s')",  # NOQA: E501
                     mgdname, p.name)
 
         # FIXME/cjones declare all the little C++ thingies that will
@@ -795,7 +904,6 @@ class GatherDecls(TcheckVisitor):
 
         self.symtab.exitScope()
 
-
     def visitManager(self, mgr):
         mgrdecl = self.symtab.lookup(mgr.name)
         pdecl = mgr.of.decl
@@ -812,13 +920,12 @@ class GatherDecls(TcheckVisitor):
         elif not isinstance(mgrdecl.type, ProtocolType):
             self.error(
                 loc,
-                "entity `%s' referenced as |manager| of `%s' is not of `protocol' type; instead it is of type `%s'",
+                "entity `%s' referenced as |manager| of `%s' is not of `protocol' type; instead it is of type `%s'",  # NOQA: E501
                 mgrname, pname, mgrdecl.type.typename())
         else:
             mgr.decl = mgrdecl
             pdecl.type.addManager(mgrdecl.type)
 
-
     def visitManagesStmt(self, mgs):
         mgsdecl = self.symtab.lookup(mgs.name)
         pdecl = mgs.manager.decl
@@ -840,7 +947,6 @@ class GatherDecls(TcheckVisitor):
             mgs.decl = mgsdecl
             pdecl.type.manages.append(mgsdecl.type)
 
-
     def visitMessageDecl(self, md):
         msgname = md.name
         loc = md.loc
@@ -864,7 +970,6 @@ class GatherDecls(TcheckVisitor):
             isdtor = True
             cdtype = self.currentProtocolDecl.type
 
-
         # enter message scope
         self.symtab.enterScope()
 
@@ -908,7 +1013,6 @@ class GatherDecls(TcheckVisitor):
         md.protocolDecl = self.currentProtocolDecl
         md.decl._md = md
 
-
     def _canonicalType(self, itype, typespec):
         loc = typespec.loc
         if itype.isIPDL():
@@ -928,7 +1032,7 @@ class GatherDecls(TcheckVisitor):
         return itype
 
 
-##-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 def checkcycles(p, stack=None):
     cycles = []
@@ -947,6 +1051,7 @@ def checkcycles(p, stack=None):
 
     return cycles
 
+
 def formatcycles(cycles):
     r = []
     for cycle in cycles:
@@ -986,8 +1091,10 @@ def fullyDefined(t, exploring=None):
             t.defined = True
             break
     else:
-        if t.isStruct():   t.defined = True
-        elif t.isUnion():  t.defined = False
+        if t.isStruct():
+            t.defined = True
+        elif t.isUnion():
+            t.defined = False
     exploring.remove(t)
 
     return t.defined
@@ -1006,7 +1113,6 @@ class CheckTypes(TcheckVisitor):
         if inc.tu.protocol:
             inc.tu.protocol.accept(self)
 
-
     def visitStructDecl(self, sd):
         if not fullyDefined(sd.decl.type):
             self.error(sd.decl.loc,
@@ -1017,7 +1123,6 @@ class CheckTypes(TcheckVisitor):
             self.error(ud.decl.loc,
                        "union `%s' is only partially defined", ud.name)
 
-
     def visitProtocol(self, p):
         self.ptype = p.decl.type
 
@@ -1028,7 +1133,7 @@ class CheckTypes(TcheckVisitor):
             if mgrtype is not None and ptype.needsMoreJuiceThan(mgrtype):
                 self.error(
                     p.decl.loc,
-                    "protocol `%s' requires more powerful send semantics than its manager `%s' provides",
+                    "protocol `%s' requires more powerful send semantics than its manager `%s' provides",  # NOQA: E501
                     pname, mgrtype.name())
 
         if ptype.isToplevel():
@@ -1047,7 +1152,6 @@ class CheckTypes(TcheckVisitor):
 
         return Visitor.visitProtocol(self, p)
 
-
     def visitManagesStmt(self, mgs):
         pdecl = mgs.manager.decl
         ptype, pname = pdecl.type, pdecl.shortname
@@ -1064,10 +1168,9 @@ class CheckTypes(TcheckVisitor):
         if not mgstype.isManagedBy(ptype):
             self.error(
                 loc,
-                "|manages| declaration in protocol `%s' does not match any |manager| declaration in protocol `%s'",
+                "|manages| declaration in protocol `%s' does not match any |manager| declaration in protocol `%s'",  # NOQA: E501
                 pname, mgsname)
 
-
     def visitManager(self, mgr):
         pdecl = mgr.of.decl
         ptype, pname = pdecl.type, pdecl.shortname
@@ -1084,10 +1187,9 @@ class CheckTypes(TcheckVisitor):
         if not mgrtype.isManagerOf(ptype):
             self.error(
                 loc,
-                "|manager| declaration in protocol `%s' does not match any |manages| declaration in protocol `%s'",
+                "|manager| declaration in protocol `%s' does not match any |manages| declaration in protocol `%s'",  # NOQA: E501
                 pname, mgrname)
 
-
     def visitMessageDecl(self, md):
         mtype, mname = md.decl.type, md.decl.progname
         ptype, pname = md.protocolDecl.type, md.protocolDecl.shortname
@@ -1103,7 +1205,7 @@ class CheckTypes(TcheckVisitor):
         if mtype.nested == INSIDE_CPOW_NESTED and (mtype.isOut() or mtype.isInout()):
             self.error(
                 loc,
-                "inside_cpow nested parent-to-child messages are verboten (here, message `%s' in protocol `%s')",
+                "inside_cpow nested parent-to-child messages are verboten (here, message `%s' in protocol `%s')",  # NOQA: E501
                 mname, pname)
 
         # We allow inside_sync messages that are themselves sync to be sent from the
@@ -1118,23 +1220,23 @@ class CheckTypes(TcheckVisitor):
         if mtype.needsMoreJuiceThan(ptype):
             self.error(
                 loc,
-                "message `%s' requires more powerful send semantics than its protocol `%s' provides",
+                "message `%s' requires more powerful send semantics than its protocol `%s' provides",  # NOQA: E501
                 mname, pname)
 
         if (mtype.isCtor() or mtype.isDtor()) and mtype.isAsync() and mtype.returns:
             self.error(loc,
                        "asynchronous ctor/dtor message `%s' declares return values",
-                       mname);
+                       mname)
 
-        if (mtype.compress and
-            (not mtype.isAsync() or mtype.isCtor() or mtype.isDtor())):
+        if (mtype.compress
+                and (not mtype.isAsync() or mtype.isCtor() or mtype.isDtor())):
 
             if mtype.isCtor() or mtype.isDtor():
                 message_type = "constructor" if mtype.isCtor() else "destructor"
                 error_message = ("%s messages can't use compression (here, in protocol `%s')" %
                                  (message_type, pname))
             else:
-                error_message = ("message `%s' in protocol `%s' requests compression but is not async" %
+                error_message = ("message `%s' in protocol `%s' requests compression but is not async" %  # NOQA: E501
                                  (mname, pname))
 
             self.error(loc, error_message)
