@@ -171,7 +171,7 @@ ProxyStream::ProxyStream(ProxyStream&& aOther)
   , mBufSize(0)
   , mPreserveStream(false)
 {
-  *this = mozilla::Move(aOther);
+  *this = std::move(aOther);
 }
 
 ProxyStream&
@@ -182,7 +182,7 @@ ProxyStream::operator=(ProxyStream&& aOther)
     MOZ_ASSERT(!result && ::GetLastError() == NO_ERROR);
   }
 
-  mStream = Move(aOther.mStream);
+  mStream = std::move(aOther.mStream);
 
   mGlobalLockedBuf = aOther.mGlobalLockedBuf;
   aOther.mGlobalLockedBuf = nullptr;
@@ -194,7 +194,7 @@ ProxyStream::operator=(ProxyStream&& aOther)
   mBufSize = aOther.mBufSize;
   aOther.mBufSize = 0;
 
-  mUnmarshaledProxy = Move(aOther.mUnmarshaledProxy);
+  mUnmarshaledProxy = std::move(aOther.mUnmarshaledProxy);
 
   mPreserveStream = aOther.mPreserveStream;
   return *this;
@@ -255,7 +255,7 @@ ProxyStream::GetPreservedStream()
   }
 
   mPreserveStream = false;
-  return ToPreservedStreamPtr(Move(cloned));
+  return ToPreservedStreamPtr(std::move(cloned));
 }
 
 bool
@@ -385,7 +385,7 @@ ProxyStream::ProxyStream(REFIID aIID, IUnknown* aObject, Environment* aEnv,
       CrashReporter::Annotation::GetHGlobalFromStreamFailure, hrAsStr);
   }
 
-  mStream = mozilla::Move(stream);
+  mStream = std::move(stream);
 
   if (streamSize) {
     CrashReporter::AnnotateCrashReport(
