@@ -1,3 +1,5 @@
+const runtime = Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULRuntime);
+
 function callback(result) {
   Assert.equal(result, Ci.nsIXULRuntime.PROCESS_TYPE_CONTENT);
   do_test_finished();
@@ -13,16 +15,14 @@ function run_test() {
   sendCommand("runtime.processType;", callback);
 
   [ [ "C", "D" ], [ "D", "C" ], [ "\u010C", "D" ], [ "D", "\u010C" ] ].forEach(
-    function (pair) {
+    function(pair) {
       do_test_pending();
       var cmp = pair[0].localeCompare(pair[1]);
       sendCommand(
-          "'"+ pair[0] +"'.localeCompare('"+ pair[1] +"');",
-          function (result) {
+          "'" + pair[0] + "'.localeCompare('" + pair[1] + "');",
+          function(result) {
               Assert.equal(cmp, result);
-              do_test_finished(); 
+              do_test_finished();
           });
     });
 }
-load('test_ipcshell_child.js');
-
