@@ -1213,6 +1213,35 @@ function FlattenIntoArray(target, source, sourceLen, start, depth, mapperFunctio
     return targetIndex;
 }
 
+// https://github.com/tc39/proposal-relative-indexing-method
+// Array.prototype.at ( index )
+function ArrayAt(index) {
+     // Step 1.
+    var O = ToObject(this);
+
+    // Step 2.
+    var len = ToLength(O.length);
+
+    // Step 3.
+    var relativeIndex = ToInteger(index);
+
+    // Steps 4-5.
+    var k;
+    if (relativeIndex >= 0) {
+        k = relativeIndex;
+    } else {
+        k = len + relativeIndex;
+    }
+
+    // Step 6.
+    if (k < 0 || k >= len) {
+        return undefined;
+    }
+
+    // Step 7.
+    return O[k];
+}
+
 function ArrayStaticConcat(arr, arg1) {
     if (arguments.length < 1)
         ThrowTypeError(JSMSG_MISSING_FUN_ARG, 0, "Array.concat");
