@@ -14,9 +14,7 @@
 
 #include "jsapi.h"
 #include "jsarray.h"
-#include "jscntxt.h"
 #include "jsnum.h"
-#include "jsobj.h"
 #ifdef XP_WIN
 # include "jswin.h"
 #endif
@@ -27,6 +25,8 @@
 #include "vm/ArrayBufferObject.h"
 #include "vm/GlobalObject.h"
 #include "vm/Interpreter.h"
+#include "vm/JSContext.h"
+#include "vm/JSObject.h"
 #include "vm/SharedMem.h"
 #include "vm/WrapperObject.h"
 
@@ -172,7 +172,7 @@ DataViewObject::getAndCheckConstructorArgs(JSContext* cx, HandleObject bufobj, c
 
     // Step 7.
     if (offset > bufferByteLength) {
-        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_ARG_INDEX_OUT_OF_RANGE, "1");
+        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_OFFSET_OUT_OF_BUFFER);
         return false;
     }
     MOZ_ASSERT(offset <= INT32_MAX);
@@ -191,7 +191,7 @@ DataViewObject::getAndCheckConstructorArgs(JSContext* cx, HandleObject bufobj, c
         // Step 9.b.
         if (offset + viewByteLength > bufferByteLength) {
             JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr,
-                                      JSMSG_ARG_INDEX_OUT_OF_RANGE, "2");
+                                      JSMSG_INVALID_DATA_VIEW_LENGTH);
             return false;
         }
     }
@@ -314,8 +314,7 @@ DataViewObject::getDataPointer(JSContext* cx, Handle<DataViewObject*> obj, uint6
 {
     const size_t TypeSize = sizeof(NativeType);
     if (offset > UINT32_MAX - TypeSize || offset + TypeSize > obj->byteLength()) {
-        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_ARG_INDEX_OUT_OF_RANGE,
-                                  "1");
+        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_OFFSET_OUT_OF_DATAVIEW);
         return SharedMem<uint8_t*>::unshared(nullptr);
     }
 
@@ -888,6 +887,16 @@ bool
 DataViewObject::byteLengthGetterImpl(JSContext* cx, const CallArgs& args)
 {
     Rooted<DataViewObject*> thisView(cx, &args.thisv().toObject().as<DataViewObject>());
+
+#ifdef NIGHTLY_BUILD
+    // Step 6,
+    if (thisView->arrayBufferEither().isDetached()) {
+        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_TYPED_ARRAY_DETACHED);
+        return false;
+    }
+#endif
+
+    // Step 7.
     args.rval().set(DataViewObject::byteLengthValue(thisView));
     return true;
 }
@@ -903,6 +912,16 @@ bool
 DataViewObject::byteOffsetGetterImpl(JSContext* cx, const CallArgs& args)
 {
     Rooted<DataViewObject*> thisView(cx, &args.thisv().toObject().as<DataViewObject>());
+
+#ifdef NIGHTLY_BUILD
+    // Step 6,
+    if (thisView->arrayBufferEither().isDetached()) {
+        JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr, JSMSG_TYPED_ARRAY_DETACHED);
+        return false;
+    }
+#endif
+
+    // Step 7.
     args.rval().set(DataViewObject::byteOffsetValue(thisView));
     return true;
 }
@@ -930,8 +949,6 @@ DataViewObject::CreatePrototype(JSContext* cx, JSProtoKey key)
 static const ClassOps DataViewObjectClassOps = {
     nullptr, /* addProperty */
     nullptr, /* delProperty */
-    nullptr, /* getProperty */
-    nullptr, /* setProperty */
     nullptr, /* enumerate */
     nullptr, /* newEnumerate */
     nullptr, /* resolve */
@@ -1036,9 +1053,9 @@ JS_GetDataViewByteLength(JSObject* obj)
 JS_FRIEND_API(JSObject*)
 JS_NewDataView(JSContext* cx, HandleObject buffer, uint32_t byteOffset, int32_t byteLength)
 {
-    RootedObject constructor(cx);
     JSProtoKey key = JSCLASS_CACHED_PROTO_KEY(&DataViewObject::class_);
-    if (!GetBuiltinConstructor(cx, key, &constructor))
+    RootedObject constructor(cx, GlobalObject::getOrCreateConstructor(cx, key));
+    if (!constructor)
         return nullptr;
 
     FixedConstructArgs<3> cargs(cx);
