@@ -6,15 +6,15 @@
 
 #include "builtin/MapObject.h"
 
-#include "jscntxt.h"
 #include "jsiter.h"
-#include "jsobj.h"
 
 #include "ds/OrderedHashTable.h"
 #include "gc/FreeOp.h"
 #include "js/Utility.h"
 #include "vm/GlobalObject.h"
 #include "vm/Interpreter.h"
+#include "vm/JSContext.h"
+#include "vm/JSObject.h"
 #include "vm/SelfHosting.h"
 #include "vm/Symbol.h"
 
@@ -128,8 +128,6 @@ namespace {
 static const ClassOps MapIteratorObjectClassOps = {
     nullptr, /* addProperty */
     nullptr, /* delProperty */
-    nullptr, /* getProperty */
-    nullptr, /* setProperty */
     nullptr, /* enumerate */
     nullptr, /* newEnumerate */
     nullptr, /* resolve */
@@ -391,8 +389,6 @@ CreateMapPrototype(JSContext* cx, JSProtoKey key)
 const ClassOps MapObject::classOps_ = {
     nullptr, // addProperty
     nullptr, // delProperty
-    nullptr, // getProperty
-    nullptr, // setProperty
     nullptr, // enumerate
     nullptr, // newEnumerate
     nullptr, // resolve
@@ -994,8 +990,6 @@ MapObject::clear(JSContext* cx, HandleObject obj)
 static const ClassOps SetIteratorObjectClassOps = {
     nullptr, /* addProperty */
     nullptr, /* delProperty */
-    nullptr, /* getProperty */
-    nullptr, /* setProperty */
     nullptr, /* enumerate */
     nullptr, /* newEnumerate */
     nullptr, /* resolve */
@@ -1221,8 +1215,6 @@ CreateSetPrototype(JSContext* cx, JSProtoKey key)
 const ClassOps SetObject::classOps_ = {
     nullptr, // addProperty
     nullptr, // delProperty
-    nullptr, // getProperty
-    nullptr, // setProperty
     nullptr, // enumerate
     nullptr, // newEnumerate
     nullptr, // resolve
