@@ -32,6 +32,7 @@ def directories(pathmodule, cwd, fixup=lambda s: s):
 DIR = directories(os.path, os.getcwd())
 PDIR = directories(posixpath, os.environ["PWD"],
                    fixup=lambda s: re.sub(r'^(\w):', r'/\1', s))
+env['CPP_UNIT_TESTS_DIR_JS_SRC'] = DIR.js_src
 
 parser = argparse.ArgumentParser(
     description='Run a spidermonkey shell build job')
@@ -256,10 +257,10 @@ elif platform.system() == 'Windows':
 # Configure flags, based on word length and cross-compilation
 if word_bits == 32:
     if platform.system() == 'Windows':
-        CONFIGURE_ARGS += ' --target=i686-pc-mingw32 --host=i686-pc-mingw32'
+        CONFIGURE_ARGS += ' --target=i686-pc-mingw32'
     elif platform.system() == 'Linux':
         if not platform.machine().startswith('arm'):
-            CONFIGURE_ARGS += ' --target=i686-pc-linux --host=i686-pc-linux'
+            CONFIGURE_ARGS += ' --target=i686-pc-linux'
 
     # Add SSE2 support for x86/x64 architectures.
     if not platform.machine().startswith('arm'):
@@ -271,7 +272,7 @@ if word_bits == 32:
         env['CXXFLAGS'] = '{0} {1}'.format(env.get('CXXFLAGS', ''), sse_flags)
 else:
     if platform.system() == 'Windows':
-        CONFIGURE_ARGS += ' --target=x86_64-pc-mingw32 --host=x86_64-pc-mingw32'
+        CONFIGURE_ARGS += ' --target=x86_64-pc-mingw32'
 
 if platform.system() == 'Linux':
     CONFIGURE_ARGS += ' --enable-stdcxx-compat'
@@ -556,7 +557,7 @@ if args.variant in ('tsan', 'msan'):
 
 # Generate stacks from minidumps.
 if use_minidump:
-    venv_python = os.path.join(OBJDIR, "_virtualenvs", "init", "bin", "python")
+    venv_python = os.path.join(OBJDIR, "_virtualenvs", "common", "bin", "python3")
     run_command([
         venv_python,
         os.path.join(DIR.source, "testing/mozbase/mozcrash/mozcrash/mozcrash.py"),
