@@ -13,6 +13,27 @@
 #include "frontend/TokenStream.h"
 #include "vm/Printer.h"
 
+// A few notes on lifetime of ParseNode trees:
+//
+// - All the `ParseNode` instances MUST BE explicitly allocated in the context's `LifoAlloc`.
+//   This is typically implemented by the `FullParseHandler` or it can be reimplemented with
+//   a custom `new_`.
+//
+// - The tree is bulk-deallocated when the parser is deallocated. Consequently, references
+//   to a subtree MUST NOT exist once the parser has been deallocated.
+//
+// - This bulk-deallocation DOES NOT run destructors.
+//
+// - Instances of `LexicalScope::Data` MUST BE allocated as instances of `ParseNode`, in the same
+//   `LifoAlloc`. They are bulk-deallocated alongside the rest of the tree.
+//
+// - Instances of `JSAtom` used throughout the tree (including instances of `PropertyName`) MUST
+//   be kept alive by the parser. This is done through an instance of `AutoKeepAtoms` held by
+//   the parser.
+//
+// - Once the parser is deallocated, the `JSAtom` instances MAY be garbage-collected.
+
+
 namespace js {
 namespace frontend {
 
@@ -22,8 +43,8 @@ class FunctionBox;
 class ObjectBox;
 
 #define FOR_EACH_PARSE_NODE_KIND(F) \
-    F(Nop) \
-    F(Semi) \
+    F(EmptyStatement) \
+    F(ExpressionStatement) \
     F(Comma) \
     F(Conditional) \
     F(Colon) \
@@ -34,14 +55,20 @@ class ObjectBox;
     F(PostIncrement) \
     F(PreDecrement) \
     F(PostDecrement) \
+    F(PropertyName) \
     F(Dot) \
     F(Elem) \
+    F(OptionalDot) \
+    F(OptionalChain) \
+    F(OptionalElem) \
+    F(OptionalCall) \
     F(Array) \
     F(Elision) \
     F(StatementList) \
     F(Label) \
     F(Object) \
     F(Call) \
+    F(Arguments) \
     F(Name) \
     F(ObjectPropertyName) \
     F(ComputedName) \
@@ -65,7 +92,6 @@ class ObjectBox;
     F(While) \
     F(DoWhile) \
     F(For) \
-    F(ComprehensionFor) \
     F(Break) \
     F(Continue) \
     F(Var) \
@@ -77,6 +103,7 @@ class ObjectBox;
     F(DeleteName) \
     F(DeleteProp) \
     F(DeleteElem) \
+    F(DeleteOptionalChain) \
     F(DeleteExpr) \
     F(Try) \
     F(Catch) \
@@ -86,9 +113,6 @@ class ObjectBox;
     F(InitialYield) \
     F(Yield) \
     F(YieldStar) \
-    F(GenExp) \
-    F(ArrayComp) \
-    F(ArrayPush) \
     F(LexicalScope) \
     F(Let) \
     F(Import) \
@@ -124,11 +148,16 @@ class ObjectBox;
     F(BitNot) \
     F(Await) \
     \
-    /* \
-     * Binary operators. \
-     * These must be in the same order as TOK_OR and friends in TokenStream.h. \
-     */ \
+    /*                                                             \
+     * Binary operators.                                           \
+     * This list must be kept in the same order in several places: \
+     *   - The binary operators in ParseNode.h                     \
+     *   - the binary operators in TokenKind.h                     \
+     *   - the precedence list in Parser.cpp                       \
+     *   - the JSOp code list in BytecodeEmitter.cpp               \
+     */                                                            \
     F(Pipeline) \
+    F(CoalesceExpr) \
     F(Or) \
     F(And) \
     F(BitOr) \
@@ -159,6 +188,9 @@ class ObjectBox;
     F(Assign) \
     F(AddAssign) \
     F(SubAssign) \
+    F(CoalesceAssign) \
+    F(OrAssign) \
+    F(AndAssign) \
     F(BitOrAssign) \
     F(BitXorAssign) \
     F(BitAndAssign) \
@@ -236,12 +268,8 @@ IsTypeofKind(ParseNodeKind kind)
  * <Statements>
  * StatementList list   pn_head: list of pn_count statements
  * If       ternary     pn_kid1: cond, pn_kid2: then, pn_kid3: else or null.
- *                            In body of a comprehension or desugared generator
- *                            expression, pn_kid2 is Yield, ArrayPush,
- *                            or (if the push was optimized away) empty
- *                            StatementList.
  * Switch   binary      pn_left: discriminant
- *                          pn_right: list of Case nodes, with at most one
+ *                      pn_right: list of Case nodes, with at most one
  *                            default node, or if there are let bindings
  *                            in the top level of the switch body's cases, a
  *                            LexicalScope node that contains the list of
@@ -256,8 +284,6 @@ IsTypeofKind(ParseNodeKind kind)
  * For      binary      pn_left: either ForIn (for-in statement),
  *                            ForOf (for-of) or ForHead (for(;;))
  *                          pn_right: body
- * ComprehensionFor;     pn_left: either ForIn or ForOf
- *              binary      pn_right: body
  * ForIn    ternary     pn_kid1: declaration or expression to left of 'in'
  *                          pn_kid2: null
  *                          pn_kid3: object expr to right of 'in'
@@ -294,10 +320,11 @@ IsTypeofKind(ParseNodeKind kind)
  *                                              pn_lexdef (NOT pn_expr) set
  *                                     pn_right: initializer
  * Return   unary       pn_kid: return expr or null
- * Semi     unary       pn_kid: expr or null statement
- *                          pn_prologue: true if Directive Prologue member
- *                              in original source, not introduced via
- *                              constant folding or other tree rewriting
+ * ExpressionStatement unary    pn_kid: expr
+ *                              pn_prologue: true if Directive Prologue member
+ *                                  in original source, not introduced via
+ *                                  constant folding or other tree rewriting
+ * EmptyStatement nullary      (no fields)
  * Label    name        pn_atom: label, pn_expr: labeled statement
  * Import   binary      pn_left: ImportSpecList import specifiers
  *                          pn_right: String module specifier
@@ -313,6 +340,9 @@ IsTypeofKind(ParseNodeKind kind)
  * Assign   binary      pn_left: lvalue, pn_right: rvalue
  * AddAssign,   binary  pn_left: lvalue, pn_right: rvalue
  * SubAssign,           pn_op: JSOP_ADD for +=, etc.
+ * CoalesceAssign,
+ * OrAssign,
+ * AndAssign,
  * BitOrAssign,
  * BitXorAssign,
  * BitAndAssign,
@@ -324,9 +354,15 @@ IsTypeofKind(ParseNodeKind kind)
  * ModAssign,
  * PowAssign
  * Conditional ternary  (cond ? trueExpr : falseExpr)
- *                          pn_kid1: cond, pn_kid2: then, pn_kid3: else
- * Or,      list        pn_head; list of pn_count subexpressions
- * And,                 All of these operators are left-associative except (**).
+ *                          pn_kid1: cond,
+ *                          pn_kid2: then,
+ *                          pn_kid3: else
+ *                          list pn_head; list of pn_count subexpressions
+ * All of these operators are left-associative except (**).
+ * PipelineExpr,
+ * CoalesceExpr
+ * Or,
+ * And,
  * BitOr,
  * BitXor,
  * BitAnd,
@@ -360,9 +396,8 @@ IsTypeofKind(ParseNodeKind kind)
  * PostIncrement,
  * PreDecrement,
  * PostDecrement
- * New      list        pn_head: list of ctor, arg1, arg2, ... argN
- *                          pn_count: 1 + N (where N is number of args)
- *                          ctor is a MEMBER expr
+ * New      binary      pn_left: ctor expression on the left of the (
+ *                          pn_right: Arguments
  * DeleteName unary     pn_kid: Name expr
  * DeleteProp unary     pn_kid: Dot expr
  * DeleteElem unary     pn_kid: Elem expr
@@ -371,15 +406,15 @@ IsTypeofKind(ParseNodeKind kind)
  *                          for a more-specific PNK_DELETE* unless constant
  *                          folding (or a similar parse tree manipulation) has
  *                          occurred
- * Dot      name        pn_expr: MEMBER expr to left of .
- *                          pn_atom: name to right of .
+ * PropertyName name    pn_atom: property name being accessed
+ * Dot      binary      pn_left: MEMBER expr to left of .
+ *                          pn_right: PropertyName to right of .
  * Elem     binary      pn_left: MEMBER expr to left of [
  *                          pn_right: expr between [ and ]
- * Call     list        pn_head: list of call, arg1, arg2, ... argN
- *                          pn_count: 1 + N (where N is number of args)
- *                          call is a MEMBER expr naming a callable object
- * GenExp   list        Exactly like Call, used for the implicit call
- *                          in the desugaring of a generator-expression.
+ * Call     binary      pn_left: callee expression on the left of the (
+ *                          pn_right: Arguments
+ * Arguments list       pn_head: list of arg1, arg2, ... argN
+ *                          pn_count: N (where N is number of args)
  * Array    list        pn_head: list of pn_count array element exprs
  *                          [,,] holes are represented by Elision nodes
  *                          pn_xflags: PN_ENDCOMMA if extra comma at end
@@ -399,8 +434,9 @@ IsTypeofKind(ParseNodeKind kind)
  *              list
  * TemplateString      pn_atom: template string atom
                 nullary     pn_op: JSOP_NOP
- * TaggedTemplate      pn_head: list of call, call site object, arg1, arg2, ... argN
- *              list        pn_count: 2 + N (N is the number of substitutions)
+ * TaggedTemplate      pn_left: tag expression
+ *              binary       pn_right: Arguments, with the first being the
+ *                           call site object, then arg1, arg2, ... argN
  * CallSiteObj list     pn_head: a Array node followed by
  *                          list of pn_count - 1 TemplateString nodes
  * RegExp   nullary     pn_objbox: RegExp model object
@@ -412,7 +448,7 @@ IsTypeofKind(ParseNodeKind kind)
  *
  * This,        unary   pn_kid: '.this' Name if function `this`, else nullptr
  * SuperBase    unary   pn_kid: '.this' Name
- *
+ * SuperCall    binary  pn_left: SuperBase pn_right: Arguments
  * SetThis      binary  pn_left: '.this' Name, pn_right: SuperCall
  *
  * LexicalScope scope   pn_u.scope.bindings: scope bindings
@@ -422,11 +458,6 @@ IsTypeofKind(ParseNodeKind kind)
  * Yield,       unary   pn_kid: expr or null
  * YieldStar,
  * Await
- * ArrayComp    list    pn_count: 1
- *                          pn_head: list of 1 element, which is block
- *                          enclosing for loop(s) and optionally
- *                          if-guarded ArrayPush
- * ArrayPush    unary   pn_kid: array comprehension expression
  * Nop          nullary
  */
 enum ParseNodeArity
@@ -550,7 +581,7 @@ class ParseNode
             ParseNode*  left;
             ParseNode*  right;
             union {
-                unsigned iflags;        /* JSITER_* flags for ParseNodeKind::{ComprehensionFor,}For node */
+                unsigned iflags;        /* JSITER_* flags for ParseNodeKind::For node */
                 bool isStatic;          /* only for ParseNodeKind::ClassMethod */
                 uint32_t offset;        /* for the emitter's use on ParseNodeKind::Case nodes */
             };
@@ -567,8 +598,7 @@ class ParseNode
                 FunctionBox* funbox;    /* function object */
             };
             ParseNode*  expr;           /* module or function body, var
-                                           initializer, argument default, or
-                                           base object of ParseNodeKind::Dot */
+                                           initializer, or argument default */
         } name;
         struct {
             LexicalScope::Data* bindings;
@@ -615,6 +645,7 @@ class ParseNode
     appendOrCreateList(ParseNodeKind kind, ParseNode* left, ParseNode* right,
                        FullParseHandler* handler, ParseContext* pc);
 
+    // include "ParseNode-inl.h" for these methods.
     inline PropertyName* name() const;
     inline JSAtom* atom() const;
 
@@ -654,7 +685,7 @@ class ParseNode
 
     bool functionIsHoisted() const {
         MOZ_ASSERT(pn_arity == PN_CODE && getKind() == ParseNodeKind::Function);
-        MOZ_ASSERT(isOp(JSOP_LAMBDA) ||        // lambda, genexpr
+        MOZ_ASSERT(isOp(JSOP_LAMBDA) ||        // lambda
                    isOp(JSOP_LAMBDA_ARROW) ||  // arrow function
                    isOp(JSOP_DEFFUN) ||        // non-body-level function statement
                    isOp(JSOP_NOP) ||           // body-level function stmt in global code
@@ -678,10 +709,10 @@ class ParseNode
      * nodes; we use it to determine the extent of the prologue.
      */
     JSAtom* isStringExprStatement() const {
-        if (getKind() == ParseNodeKind::Semi) {
+        if (getKind() == ParseNodeKind::ExpressionStatement) {
             MOZ_ASSERT(pn_arity == PN_UNARY);
             ParseNode* kid = pn_kid;
-            if (kid && kid->getKind() == ParseNodeKind::String && !kid->pn_parens)
+            if (kid->getKind() == ParseNodeKind::String && !kid->pn_parens)
                 return kid->pn_atom;
         }
         return nullptr;
@@ -711,22 +742,6 @@ class ParseNode
         return false;
     }
 
-    ParseNode* generatorExpr() const {
-        MOZ_ASSERT(isKind(ParseNodeKind::GenExp));
-
-        ParseNode* callee = this->pn_head;
-        MOZ_ASSERT(callee->isKind(ParseNodeKind::Function));
-
-        ParseNode* paramsBody = callee->pn_body;
-        MOZ_ASSERT(paramsBody->isKind(ParseNodeKind::ParamsBody));
-
-        ParseNode* body = paramsBody->last();
-        MOZ_ASSERT(body->isKind(ParseNodeKind::StatementList));
-        MOZ_ASSERT(body->last()->isKind(ParseNodeKind::LexicalScope) ||
-                   body->last()->isKind(ParseNodeKind::ComprehensionFor));
-        return body->last();
-    }
-
     /*
      * Compute a pointer to the last element in a singly-linked list. NB: list
      * must be non-empty for correct PN_LAST usage -- this is asserted!
@@ -764,8 +779,12 @@ class ParseNode
     }
 
     void append(ParseNode* pn) {
-        MOZ_ASSERT(pn_arity == PN_LIST);
         MOZ_ASSERT(pn->pn_pos.begin >= pn_pos.begin);
+        appendWithoutOrderAssumption(pn);
+    }
+
+    void appendWithoutOrderAssumption(ParseNode* pn) {
+        MOZ_ASSERT(pn_arity == PN_LIST);
         pn_pos.end = pn->pn_pos.end;
         *pn_tail = pn;
         pn_tail = &pn->pn_next;
@@ -943,7 +962,7 @@ struct CodeNode : public ParseNode
         MOZ_ASSERT_IF(kind == ParseNodeKind::Module, op == JSOP_NOP);
         MOZ_ASSERT(op == JSOP_NOP || // statement, module
                    op == JSOP_LAMBDA_ARROW || // arrow function
-                   op == JSOP_LAMBDA); // expression, method, comprehension, accessor, &c.
+                   op == JSOP_LAMBDA); // expression, method, accessor, &c.
         MOZ_ASSERT(!pn_body);
         MOZ_ASSERT(!pn_objbox);
     }
@@ -1188,30 +1207,50 @@ class RegExpLiteral : public NullaryNode
     }
 };
 
-class PropertyAccess : public ParseNode
+class PropertyAccessBase : public BinaryNode
 {
   public:
-    PropertyAccess(ParseNode* lhs, PropertyName* name, uint32_t begin, uint32_t end)
-      : ParseNode(ParseNodeKind::Dot, JSOP_NOP, PN_NAME, TokenPos(begin, end))
+    /*
+     * PropertyAccess nodes can have any expression/'super' as left-hand
+     * side, but the name must be a ParseNodeKind::PropertyName node.
+     */
+    PropertyAccessBase(ParseNodeKind kind, ParseNode* lhs, ParseNode* name, uint32_t begin, uint32_t end)
+      : BinaryNode(kind, JSOP_NOP, TokenPos(begin, end), lhs, name)
     {
         MOZ_ASSERT(lhs != nullptr);
         MOZ_ASSERT(name != nullptr);
-        pn_u.name.expr = lhs;
-        pn_u.name.atom = name;
-    }
-
-    static bool test(const ParseNode& node) {
-        bool match = node.isKind(ParseNodeKind::Dot);
-        MOZ_ASSERT_IF(match, node.isArity(PN_NAME));
-        return match;
     }
 
     ParseNode& expression() const {
-        return *pn_u.name.expr;
+        return *pn_u.binary.left;
+    }
+
+    static bool test(const ParseNode& node) {
+        bool match = node.isKind(ParseNodeKind::Dot) ||
+                     node.isKind(ParseNodeKind::OptionalDot);
+        MOZ_ASSERT_IF(match, node.isArity(PN_BINARY));
+        MOZ_ASSERT_IF(match, node.pn_right->isKind(ParseNodeKind::PropertyName));
+        return match;
     }
 
     PropertyName& name() const {
-        return *pn_u.name.atom->asPropertyName();
+        return *pn_u.binary.right->pn_atom->asPropertyName();
+    }
+};
+
+class PropertyAccess : public PropertyAccessBase
+{
+  public:
+    PropertyAccess(ParseNode* lhs, ParseNode* name, uint32_t begin, uint32_t end)
+        : PropertyAccessBase(ParseNodeKind::Dot, lhs, name, begin, end) {
+      MOZ_ASSERT(lhs);
+      MOZ_ASSERT(name);
+    }
+
+    static bool test(const ParseNode& node) {
+      bool match = node.isKind(ParseNodeKind::Dot);
+      MOZ_ASSERT_IF(match, node.is<PropertyAccessBase>());
+      return match;
     }
 
     bool isSuper() const {
@@ -1219,28 +1258,73 @@ class PropertyAccess : public ParseNode
         return expression().isKind(ParseNodeKind::SuperBase);
     }
 };
+  
+class OptionalPropertyAccess : public PropertyAccessBase {
+  public:
+    OptionalPropertyAccess(ParseNode* lhs, ParseNode* name, uint32_t begin, uint32_t end)
+        : PropertyAccessBase(ParseNodeKind::OptionalDot, lhs, name, begin, end) {
+      MOZ_ASSERT(lhs);
+      MOZ_ASSERT(name);
+    }
+  
+    static bool test(const ParseNode& node) {
+      bool match = node.isKind(ParseNodeKind::OptionalDot);
+      MOZ_ASSERT_IF(match, node.is<PropertyAccessBase>());
+      return match;
+    }
+};
 
-class PropertyByValue : public ParseNode
+class PropertyByValueBase : public ParseNode
 {
   public:
-    PropertyByValue(ParseNode* lhs, ParseNode* propExpr, uint32_t begin, uint32_t end)
-      : ParseNode(ParseNodeKind::Elem, JSOP_NOP, PN_BINARY, TokenPos(begin, end))
+    PropertyByValueBase(ParseNodeKind kind, ParseNode* lhs, ParseNode* propExpr,
+                        uint32_t begin, uint32_t end)
+      : ParseNode(kind, JSOP_NOP, PN_BINARY, TokenPos(begin, end))
     {
         pn_u.binary.left = lhs;
         pn_u.binary.right = propExpr;
     }
 
+    ParseNode& expression() const {
+        return *pn_u.binary.left;
+    }
+
     static bool test(const ParseNode& node) {
-        bool match = node.isKind(ParseNodeKind::Elem);
+        bool match = node.isKind(ParseNodeKind::Elem) ||
+                     node.isKind(ParseNodeKind::OptionalElem);
         MOZ_ASSERT_IF(match, node.isArity(PN_BINARY));
         return match;
     }
+};
+
+class PropertyByValue : public PropertyByValueBase {
+  public:
+    PropertyByValue(ParseNode* lhs, ParseNode* propExpr, uint32_t begin, uint32_t end)
+        : PropertyByValueBase(ParseNodeKind::Elem, lhs, propExpr, begin, end) {}
+  
+    static bool test(const ParseNode& node) {
+      bool match = node.isKind(ParseNodeKind::Elem);
+      MOZ_ASSERT_IF(match, node.is<PropertyByValueBase>());
+      return match;
+    }
 
     bool isSuper() const {
         return pn_left->isKind(ParseNodeKind::SuperBase);
     }
 };
 
+class OptionalPropertyByValue : public PropertyByValueBase {
+  public:
+    OptionalPropertyByValue(ParseNode* lhs, ParseNode* propExpr, uint32_t begin, uint32_t end)
+        : PropertyByValueBase(ParseNodeKind::OptionalElem, lhs, propExpr, begin, end) {}
+  
+    static bool test(const ParseNode& node) {
+      bool match = node.isKind(ParseNodeKind::OptionalElem);
+      MOZ_ASSERT_IF(match, node.is<PropertyByValueBase>());
+      return match;
+    }
+};
+
 /*
  * A CallSiteNode represents the implicit call site object argument in a TaggedTemplate.
  */
@@ -1360,18 +1444,14 @@ class ParseNodeAllocator
 {
   public:
     explicit ParseNodeAllocator(JSContext* cx, LifoAlloc& alloc)
-      : cx(cx), alloc(alloc), freelist(nullptr)
+      : cx(cx), alloc(alloc)
     {}
 
     void* allocNode();
-    void freeNode(ParseNode* pn);
-    ParseNode* freeTree(ParseNode* pn);
-    void prepareNodeForMutation(ParseNode* pn);
 
   private:
     JSContext* cx;
     LifoAlloc& alloc;
-    ParseNode* freelist;
 };
 
 inline bool
@@ -1444,43 +1524,36 @@ AccessorTypeToJSOp(AccessorType atype)
     }
 }
 
-enum FunctionSyntaxKind
+enum class FunctionSyntaxKind
 {
+    // A non-arrow function expression.
     Expression,
+
+    // A named function appearing as a Statement.
     Statement,
+
     Arrow,
     Method,
     ClassConstructor,
     DerivedClassConstructor,
     Getter,
-    GetterNoExpressionClosure,
     Setter,
-    SetterNoExpressionClosure
 };
 
 static inline bool
 IsConstructorKind(FunctionSyntaxKind kind)
 {
-    return kind == ClassConstructor || kind == DerivedClassConstructor;
-}
-
-static inline bool
-IsGetterKind(FunctionSyntaxKind kind)
-{
-    return kind == Getter || kind == GetterNoExpressionClosure;
-}
-
-static inline bool
-IsSetterKind(FunctionSyntaxKind kind)
-{
-    return kind == Setter || kind == SetterNoExpressionClosure;
+    return kind == FunctionSyntaxKind::ClassConstructor ||
+           kind == FunctionSyntaxKind::DerivedClassConstructor;
 }
 
 static inline bool
 IsMethodDefinitionKind(FunctionSyntaxKind kind)
 {
-    return kind == Method || IsConstructorKind(kind) ||
-           IsGetterKind(kind) || IsSetterKind(kind);
+    return IsConstructorKind(kind) ||
+           kind == FunctionSyntaxKind::Method ||
+           kind == FunctionSyntaxKind::Getter ||
+           kind == FunctionSyntaxKind::Setter;
 }
 
 static inline ParseNode*
