@@ -1122,14 +1122,14 @@ class ArrayMemoryView : public MDefinitionVisitorDefaultNoop
 
   public:
     void visitResumePoint(MResumePoint* rp);
-    void visitArrayState(MArrayState* ins);
-    void visitStoreElement(MStoreElement* ins);
-    void visitLoadElement(MLoadElement* ins);
-    void visitSetInitializedLength(MSetInitializedLength* ins);
-    void visitInitializedLength(MInitializedLength* ins);
-    void visitArrayLength(MArrayLength* ins);
-    void visitMaybeCopyElementsForWrite(MMaybeCopyElementsForWrite* ins);
-    void visitConvertElementsToDoubles(MConvertElementsToDoubles* ins);
+    void visitArrayState(MArrayState* ins) override;
+    void visitStoreElement(MStoreElement* ins) override;
+    void visitLoadElement(MLoadElement* ins) override;
+    void visitSetInitializedLength(MSetInitializedLength* ins) override;
+    void visitInitializedLength(MInitializedLength* ins) override;
+    void visitArrayLength(MArrayLength* ins) override;
+    void visitMaybeCopyElementsForWrite(MMaybeCopyElementsForWrite* ins) override;
+    void visitConvertElementsToDoubles(MConvertElementsToDoubles* ins) override;
 };
 
 const char* ArrayMemoryView::phaseName = "Scalar Replacement of Array";
