@@ -3,34 +3,30 @@
 
 /*---
 esid: sec-array.prototype.foreach
-es5id: 15.4.4.18-7-b-8
+es5id: 15.4.4.18-7-b-4
 description: >
-    Array.prototype.forEach - deleting own property causes index
-    property not to be visited on an Array-like object
+    Array.prototype.forEach - properties added into own object after
+    current position are visited on an Array-like object
 ---*/
 
-        var accessed = false;
-        var testResult = true;
+        var testResult = false;
 
         function callbackfn(val, idx, obj) {
-            accessed = true;
-            if (idx === 1) {
-                testResult = false;
+            if (idx === 1 && val === 1) {
+                testResult = true;
             }
         }
 
         var obj = { length: 2 };
 
-        Object.defineProperty(obj, "1", {
-            get: function () {
-                return 6.99;
-            },
-            configurable: true
-        });
-
         Object.defineProperty(obj, "0", {
             get: function () {
-                delete obj[1];
+                Object.defineProperty(obj, "1", {
+                    get: function () {
+                        return 1;
+                    },
+                    configurable: true
+                });
                 return 0;
             },
             configurable: true
@@ -39,6 +35,5 @@ description: >
         Array.prototype.forEach.call(obj, callbackfn);
 
 assert(testResult, 'testResult !== true');
-assert(accessed, 'accessed !== true');
 
 reportCompare(0, 0);
