@@ -3,17 +3,16 @@
 
 /*---
 esid: sec-array.prototype.map
-es5id: 15.4.4.19-5-11
-description: Array.prototype.map - String object can be used as thisArg
+es5id: 15.4.4.19-5-21
+description: Array.prototype.map - the global object can be used as thisArg
 ---*/
 
-        var objString = new String();
-
+var global = this;
         function callbackfn(val, idx, obj) {
-            return this === objString;
+            return this === global;
         }
 
-        var testResult = [11].map(callbackfn, objString);
+        var testResult = [11].map(callbackfn, this);
 
 assert.sameValue(testResult[0], true, 'testResult[0]');
 
