@@ -2,12 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.12.1.1-g2-3
-description: A JSONString may not be delimited by Uncode escaped quotes
+es5id: 15.12.1.1-g5-2
+description: >
+    A JSONStringCharacter UnicodeEscape may not have fewer than 4 hex
+    characters
 ---*/
 
 assert.throws(SyntaxError, function() {
-  JSON.parse("\\u0022abc\\u0022");
+        JSON.parse('"\\u005"') 
 });
 
 reportCompare(0, 0);
