@@ -2,14 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.2-2-21
+es5id: 15.2.3.2-2-30
 description: >
     Object.getPrototypeOf returns the [[Prototype]] of its parameter
-    (Array object)
+    (the global object)
 ---*/
 
-        var arr = [1, 2, 3];
+        var proto = Object.getPrototypeOf(this);
 
-assert.sameValue(Object.getPrototypeOf(arr), Array.prototype, 'Object.getPrototypeOf(arr)');
+assert.sameValue(proto.isPrototypeOf(this), true, 'proto.isPrototypeOf(this)');
 
 reportCompare(0, 0);
