@@ -2,12 +2,10 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.13-2-8
-description: Object.isExtensible returns true for all built-in objects (Math)
+es5id: 15.2.3.13-1-2
+description: Object.isExtensible does not throw TypeError if 'O' is null
 ---*/
 
-  var e = Object.isExtensible(Math);
-
-assert.sameValue(e, true, 'e');
+    Object.isExtensible(null);
 
 reportCompare(0, 0);
