@@ -2,13 +2,13 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.12-3-23
+es5id: 15.2.3.12-3-13
 description: >
     Object.isFrozen returns false for all built-in objects
-    (ReferenceError)
+    (Number.prototype)
 ---*/
 
-  var b = Object.isFrozen(ReferenceError);
+  var b = Object.isFrozen(Number.prototype);
 
 assert.sameValue(b, false, 'b');
 
