@@ -2,16 +2,17 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.14-5-9
+es5id: 15.2.3.14-5-6
 description: >
-    Object.keys - inherted enumerable accessor property that is
-    over-ridden by non-enumerable own data property is not defined in
-    returned array
+    Object.keys - inherited enumerable accessor property of 'O' is not
+    defined in returned array
 ---*/
 
         var proto = {};
-        Object.defineProperty(proto, "prop", {
-            get: function () { },
+        Object.defineProperty(proto, "inheritedProp", {
+            get: function () {
+                return 1003;
+            },
             enumerable: true,
             configurable: true
         });
@@ -20,15 +21,17 @@ description: >
 
         var obj = new Con();
         Object.defineProperty(obj, "prop", {
-            value: 1003,
-            enumerable: false,
+            get: function () {
+                return 1004;
+            },
+            enumerable: true,
             configurable: true
         });
 
         var arr = Object.keys(obj);
 
         for (var p in arr) {
-            assert.notSameValue(arr[p], "prop", 'arr[p]');
+            assert.notSameValue(arr[p], "inheritedProp", 'arr[p]');
         }
 
 reportCompare(0, 0);
