@@ -2,21 +2,21 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.10-3-3
+es5id: 15.2.3.10-3-14
 description: >
-    Object.preventExtensions - indexed properties cannot be added into
-    a Function object
+    Object.preventExtensions - named properties cannot be added into
+    an Array object
 includes: [propertyHelper.js]
 ---*/
 
-var obj = function () { };
+var obj = [];
 
 assert(Object.isExtensible(obj));
 Object.preventExtensions(obj);
 assert(!Object.isExtensible(obj));
 
-verifyNotWritable(obj, "0", "nocheck");
+verifyNotWritable(obj, "exName", "nocheck");
 
-assert(!obj.hasOwnProperty("0"));
+assert(!obj.hasOwnProperty("exName"));
 
 reportCompare(0, 0);
