@@ -2,14 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 8.12.1-1_33
+es5id: 8.12.1-1_4
 description: >
-    Properties - [[HasOwnProperty]] (configurable, enumerable own
-    setter property)
+    Properties - [[HasOwnProperty]] (non-writable, non-configurable,
+    non-enumerable own value property)
 ---*/
 
     var o = {};
-    Object.defineProperty(o, "foo", {set: function() {;}, enumerable:true, configurable:true});
+    Object.defineProperty(o, "foo", {value: 42});
 
 assert(o.hasOwnProperty("foo"), 'o.hasOwnProperty("foo") !== true');
 
