@@ -2,8 +2,8 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-info: The production x >>>= y is the same as x = x >>> y
-es5id: 11.13.2_A4.8_T2.8
+info: The production x <<= y is the same as x = x << y
+es5id: 11.13.2_A4.6_T2.8
 description: >
     Type(x) is different from Type(y) and both types vary between
     Boolean (primitive or object) and Undefined
@@ -13,30 +13,30 @@ var x;
 
 //CHECK#1
 x = true;
-x >>>= undefined;
+x <<= undefined;
 if (x !== 1) {
-  $ERROR('#1: x = true; x >>>= undefined; x === 1. Actual: ' + (x));
+  $ERROR('#1: x = true; x <<= undefined; x === 1. Actual: ' + (x));
 }
 
 //CHECK#2
 x = undefined;
-x >>>= true;
+x <<= true;
 if (x !== 0) {
-  $ERROR('#2: x = undefined; x >>>= true; x === 0. Actual: ' + (x));
+  $ERROR('#2: x = undefined; x <<= true; x === 0. Actual: ' + (x));
 }
 
 //CHECK#3
 x = new Boolean(true);
-x >>>= undefined;
+x <<= undefined;
 if (x !== 1) {
-  $ERROR('#3: x = new Boolean(true); x >>>= undefined; x === 1. Actual: ' + (x));
+  $ERROR('#3: x = new Boolean(true); x <<= undefined; x === 1. Actual: ' + (x));
 }
 
 //CHECK#4
 x = undefined;
-x >>>= new Boolean(true);
+x <<= new Boolean(true);
 if (x !== 0) {
-  $ERROR('#4: x = undefined; x >>>= new Boolean(true); x === 0. Actual: ' + (x));
+  $ERROR('#4: x = undefined; x <<= new Boolean(true); x === 0. Actual: ' + (x));
 }
 
 reportCompare(0, 0);
