@@ -5,30 +5,30 @@
 info: |
     If Type(Primitive(x)) is not String or Type(Primitive(y)) is not String,
     then operator x > y returns ToNumber(x) > ToNumber(y)
-es5id: 11.8.2_A3.1_T2.9
+es5id: 11.8.2_A3.1_T2.6
 description: >
     Type(Primitive(x)) is different from Type(Primitive(y)) and both
-    types vary between Boolean (primitive or object) and Null
+    types vary between String (primitive or object) and Undefined
 ---*/
 
 //CHECK#1
-if (true > null !== true) {
-  $ERROR('#1: true > null === true');
+if ("1" > undefined !== false) {
+  $ERROR('#1: "1" > undefined === false');
 }
 
 //CHECK#2
-if (null > true !== false) {
-  $ERROR('#2: null > true === false');
+if (undefined > "1" !== false) {
+  $ERROR('#2: undefined > "1" === false');
 }
 
 //CHECK#3
-if (new Boolean(true) > null !== true) {
-  $ERROR('#3: new Boolean(true) > null === true');
+if (new String("1") > undefined !== false) {
+  $ERROR('#3: new String("1") > undefined === false');
 }
 
 //CHECK#4
-if (null > new Boolean(true) !== false) {
-  $ERROR('#4: null > new Boolean(true) === false');
+if (undefined > new String("1") !== false) {
+  $ERROR('#4: undefined > new String("1") === false');
 }
 
 reportCompare(0, 0);
